/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FL3NGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FL3NGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FL3NGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FL3NGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FL3NGR::Heavy_WSTD_FL3NGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_tcqCC40R);
  numBytes += sLine_init(&sLine_7iI2FIwz);
  numBytes += sLine_init(&sLine_kcBju681);
  numBytes += sLine_init(&sLine_rEHoyQz2);
  numBytes += sLine_init(&sLine_JXeZvpQL);
  numBytes += sBiquad_init(&sBiquad_s_b2Wqmk5H);
  numBytes += sLine_init(&sLine_cTcU1J1G);
  numBytes += sLine_init(&sLine_aToP3TOa);
  numBytes += sLine_init(&sLine_iGlLF8XB);
  numBytes += sLine_init(&sLine_y4nENucK);
  numBytes += sBiquad_init(&sBiquad_s_bQ1V9l5F);
  numBytes += sLine_init(&sLine_fp0Wa5tk);
  numBytes += sLine_init(&sLine_x8nV1y5C);
  numBytes += sLine_init(&sLine_rFtgVc5Y);
  numBytes += sLine_init(&sLine_2rbWQfBq);
  numBytes += sLine_init(&sLine_i8mIQpUl);
  numBytes += sBiquad_init(&sBiquad_s_WMjjMP0H);
  numBytes += sLine_init(&sLine_mHiMPZQj);
  numBytes += sLine_init(&sLine_4d5kDSLq);
  numBytes += sLine_init(&sLine_J7qbvHRr);
  numBytes += sLine_init(&sLine_H70voZQM);
  numBytes += sLine_init(&sLine_W1FLm0AB);
  numBytes += sBiquad_init(&sBiquad_s_qx2aLIEB);
  numBytes += sLine_init(&sLine_9zAbs7dz);
  numBytes += sLine_init(&sLine_RYEYNDiy);
  numBytes += sLine_init(&sLine_XRh2uJVw);
  numBytes += sLine_init(&sLine_UApHMuFn);
  numBytes += sBiquad_init(&sBiquad_s_rNEx0T31);
  numBytes += sLine_init(&sLine_QDFw4tkg);
  numBytes += sLine_init(&sLine_lNlcjPvE);
  numBytes += sLine_init(&sLine_m2FqzZdX);
  numBytes += sLine_init(&sLine_RVr9glzQ);
  numBytes += sLine_init(&sLine_g6eCNDUT);
  numBytes += sBiquad_init(&sBiquad_s_5akfb8Mh);
  numBytes += sLine_init(&sLine_jPdgON4x);
  numBytes += sPhasor_k_init(&sPhasor_PKtSgFhN, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_XBEQuLmN);
  numBytes += sRPole_init(&sRPole_iOy1aLaI);
  numBytes += sRPole_init(&sRPole_2zWtRCvS);
  numBytes += sTabhead_init(&sTabhead_KXPcBWP3, &hTable_cA5rHVGy);
  numBytes += sTabread_init(&sTabread_50ZHRfu7, &hTable_cA5rHVGy, false);
  numBytes += sTabread_init(&sTabread_PVpdqOV8, &hTable_cA5rHVGy, false);
  numBytes += sLine_init(&sLine_0jiNV161);
  numBytes += sTabhead_init(&sTabhead_FRebSj7W, &hTable_yqMtosOF);
  numBytes += sTabread_init(&sTabread_zShqMlpk, &hTable_yqMtosOF, false);
  numBytes += sTabread_init(&sTabread_V6r0xve3, &hTable_yqMtosOF, false);
  numBytes += sLine_init(&sLine_AFbtw5q2);
  numBytes += sTabwrite_init(&sTabwrite_HrtSMXdV, &hTable_yqMtosOF);
  numBytes += sTabwrite_init(&sTabwrite_FZ96nbf0, &hTable_cA5rHVGy);
  numBytes += sLine_init(&sLine_IoocO4T4);
  numBytes += sPhasor_k_init(&sPhasor_S3AGkLt4, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_bZHEiyDW);
  numBytes += sRPole_init(&sRPole_imalDxZF);
  numBytes += sRPole_init(&sRPole_tGBzcY6Z);
  numBytes += sTabhead_init(&sTabhead_2CDDGwwY, &hTable_OQxq8Ffk);
  numBytes += sTabread_init(&sTabread_p2jMAa6p, &hTable_OQxq8Ffk, false);
  numBytes += sTabread_init(&sTabread_V0fgmksX, &hTable_OQxq8Ffk, false);
  numBytes += sLine_init(&sLine_8TQojPiB);
  numBytes += sTabhead_init(&sTabhead_K4PO5IKi, &hTable_uKorntAo);
  numBytes += sTabread_init(&sTabread_A3fxbbAT, &hTable_uKorntAo, false);
  numBytes += sTabread_init(&sTabread_clUWDQJk, &hTable_uKorntAo, false);
  numBytes += sLine_init(&sLine_sQoC69mn);
  numBytes += sTabwrite_init(&sTabwrite_NSZR8yTG, &hTable_uKorntAo);
  numBytes += sTabwrite_init(&sTabwrite_0fFr9Nwq, &hTable_OQxq8Ffk);
  numBytes += sLine_init(&sLine_uPnfAmee);
  numBytes += sPhasor_k_init(&sPhasor_rYky22Ca, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_D7X0e3Oc);
  numBytes += sRPole_init(&sRPole_T5EPiauS);
  numBytes += sRPole_init(&sRPole_wiEKCUBa);
  numBytes += sTabhead_init(&sTabhead_o3Dw67tI, &hTable_J4RDg2Sc);
  numBytes += sTabread_init(&sTabread_Sg4QR3FX, &hTable_J4RDg2Sc, false);
  numBytes += sTabread_init(&sTabread_p25QAGUp, &hTable_J4RDg2Sc, false);
  numBytes += sLine_init(&sLine_D8ogDojP);
  numBytes += sTabhead_init(&sTabhead_Uk0JYElV, &hTable_esHiXFKQ);
  numBytes += sTabread_init(&sTabread_xftieUDt, &hTable_esHiXFKQ, false);
  numBytes += sTabread_init(&sTabread_VKRQ6xQs, &hTable_esHiXFKQ, false);
  numBytes += sLine_init(&sLine_77mqAowP);
  numBytes += sTabwrite_init(&sTabwrite_g1i8JYvN, &hTable_esHiXFKQ);
  numBytes += sTabwrite_init(&sTabwrite_JFdU9lxR, &hTable_J4RDg2Sc);
  numBytes += cVar_init_f(&cVar_oz7C4UyQ, 0.0f);
  numBytes += cVar_init_f(&cVar_ldEwEk0A, 0.0f);
  numBytes += cVar_init_f(&cVar_cFNayMOe, 0.0f);
  numBytes += cVar_init_f(&cVar_uHLQXCqW, 0.0f);
  numBytes += cSlice_init(&cSlice_oD13NZnT, 1, -1);
  numBytes += cVar_init_f(&cVar_iMdy0TWo, 1337.0f);
  numBytes += cVar_init_f(&cVar_cUc0cRCh, 0.0f);
  numBytes += cIf_init(&cIf_3CD7GzW3, false);
  numBytes += cIf_init(&cIf_OnORbVOz, false);
  numBytes += cBinop_init(&cBinop_ENax6zPm, 0.0f); // __pow
  numBytes += cIf_init(&cIf_aHrGOSk7, false);
  numBytes += cBinop_init(&cBinop_HhiBxHeD, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_YdMO6yLq, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_rACyRTbW, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_xBwCBx3o, 0.0f);
  numBytes += cIf_init(&cIf_D21VapRk, false);
  numBytes += cIf_init(&cIf_M1C5PvSh, false);
  numBytes += cBinop_init(&cBinop_ad7dlIO2, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ynzp2oup, false);
  numBytes += cBinop_init(&cBinop_SoXvGsOT, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_DRjO5N1y, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_yO54bVCz, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_iUm41Ccy, 0.0f);
  numBytes += cIf_init(&cIf_7tJ7gj5M, false);
  numBytes += cIf_init(&cIf_IUHp6MbU, false);
  numBytes += cBinop_init(&cBinop_rh7SrqIY, 0.0f); // __pow
  numBytes += cIf_init(&cIf_vMlWDihI, false);
  numBytes += cBinop_init(&cBinop_FIBoWOEZ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_6qfgeMFy, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_YlKf1nhI, -15.0f); // __eq
  numBytes += cIf_init(&cIf_h3q0aBMl, false);
  numBytes += cSlice_init(&cSlice_oy5mgFBF, 1, -1);
  numBytes += cVar_init_f(&cVar_xEY5fKVz, 0.0f);
  numBytes += cSlice_init(&cSlice_v91JVVQF, 1, -1);
  numBytes += cVar_init_f(&cVar_VVlbafAc, 0.0f);
  numBytes += cSlice_init(&cSlice_p3qgN0UC, 1, -1);
  numBytes += cVar_init_f(&cVar_7EFwl6WE, 0.0f);
  numBytes += cSlice_init(&cSlice_HBjbMSmS, 1, -1);
  numBytes += cVar_init_f(&cVar_JEAlLkZg, 0.313f);
  numBytes += cBinop_init(&cBinop_XnhoRMho, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_BvTywMKd, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_7ljVfgM5, 0.0f);
  numBytes += cVar_init_f(&cVar_AnZbbXRp, 1337.0f);
  numBytes += cVar_init_f(&cVar_NjaQXfbR, 0.3f);
  numBytes += cBinop_init(&cBinop_Nhvgmdwr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JQJi4G1o, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DKlBjMW2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8kR9v5Xf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nmbJccHk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XyUHIQni, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cdHzXtND, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Wq2qf5Oy, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_9JwHs3hy, 0.0f);
  numBytes += cVar_init_f(&cVar_M7UNEPrf, 1337.0f);
  numBytes += cVar_init_f(&cVar_csVitYPN, 0.313f);
  numBytes += cBinop_init(&cBinop_uRZJ7YrB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XUyecwPP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EA2lhL31, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xZrvamYi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ko1rGWQz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RMjXyed9, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_dJsg2Vpv, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_9cNPZkHv, 0.0f);
  numBytes += cVar_init_f(&cVar_4BD9Jdp2, 1037.0f);
  numBytes += cVar_init_f(&cVar_0ddChBYI, 0.4f);
  numBytes += cBinop_init(&cBinop_iDZIJop5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HzLOiJ90, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Hms15U2w, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_doEiW49l, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_agqriNwf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ogJtDv5C, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_9tooU4Uk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iNCmDaUN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BF8IelrZ, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_hBiqHxts, 1, -1);
  numBytes += cVar_init_f(&cVar_TJCeWTFL, 1337.0f);
  numBytes += cVar_init_f(&cVar_EjLhABz0, 0.0f);
  numBytes += cIf_init(&cIf_7DapzRxl, false);
  numBytes += cIf_init(&cIf_jwvpT02M, false);
  numBytes += cBinop_init(&cBinop_YZDgqVTW, 0.0f); // __pow
  numBytes += cIf_init(&cIf_eQJWDn9J, false);
  numBytes += cBinop_init(&cBinop_SuhHhsLr, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_hRGHEgwT, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_ebUxfjQe, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_NKDjhzUN, 0.0f);
  numBytes += cIf_init(&cIf_m9Y1kPMR, false);
  numBytes += cIf_init(&cIf_9QmxgK3e, false);
  numBytes += cBinop_init(&cBinop_X6EwV6n9, 0.0f); // __pow
  numBytes += cIf_init(&cIf_mjuHmkvO, false);
  numBytes += cBinop_init(&cBinop_KWmGuT8x, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ZZqtD6AG, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_SMChB942, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_ldGrKpnj, 0.0f);
  numBytes += cIf_init(&cIf_5lc0J818, false);
  numBytes += cIf_init(&cIf_GGwgBBhK, false);
  numBytes += cBinop_init(&cBinop_VH4CqPsI, 0.0f); // __pow
  numBytes += cIf_init(&cIf_61qkG2zk, false);
  numBytes += cBinop_init(&cBinop_PfawCcOI, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_W1ijtJYM, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_OtQSdTx2, -15.0f); // __eq
  numBytes += cIf_init(&cIf_QzrCEHGw, false);
  numBytes += cSlice_init(&cSlice_vzNEG3O8, 1, -1);
  numBytes += cVar_init_f(&cVar_uPwabecF, 0.0f);
  numBytes += cSlice_init(&cSlice_toReXj7S, 1, -1);
  numBytes += cVar_init_f(&cVar_8hsryfdK, 0.0f);
  numBytes += cSlice_init(&cSlice_jOvMuZA7, 1, -1);
  numBytes += cVar_init_f(&cVar_LF44zxdI, 0.0f);
  numBytes += cSlice_init(&cSlice_QUtnOPma, 1, -1);
  numBytes += cVar_init_f(&cVar_QqhdjAnx, 0.313f);
  numBytes += cBinop_init(&cBinop_eV1oGnzS, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ILh0nrVY, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_yCvmXnrh, 0.0f);
  numBytes += cVar_init_f(&cVar_bpg6j99l, 1337.0f);
  numBytes += cVar_init_f(&cVar_7U4d34AQ, 0.3f);
  numBytes += cBinop_init(&cBinop_sPsrBRKy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jXEEcUT7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4dYgFyBt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6t7nT2g2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RbrEKLgT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qwm10DbI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9gFKS1lc, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_fU2OpwG7, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_xKQaudQA, 0.0f);
  numBytes += cVar_init_f(&cVar_uxNTZpqS, 1337.0f);
  numBytes += cVar_init_f(&cVar_OPyZCddF, 0.313f);
  numBytes += cBinop_init(&cBinop_nth0L5us, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_w6vMObcW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3ZpQIYDq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_r1TxioJx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DeRF12Ae, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_I1d800Qr, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_QsX98j3p, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_oJCtGmUB, 0.0f);
  numBytes += cVar_init_f(&cVar_RPOUuqrI, 1037.0f);
  numBytes += cVar_init_f(&cVar_tgYa4xj5, 0.4f);
  numBytes += cBinop_init(&cBinop_a3CzXAXe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KwGIderH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MAOrSjnr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WPijBM2X, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vS2c8OVf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fE5A4TxA, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_lXIherSm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3clxlTvb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LsTXWmrX, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_zG2xdPZU, 5705.6f);
  numBytes += cVar_init_f(&cVar_apT5qN4y, 313.3f);
  numBytes += cBinop_init(&cBinop_Dct0VU3s, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_cbp4mVFg, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_mjP5At0o, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_u3yM78cB, 0.0f);
  numBytes += cVar_init_f(&cVar_vK5OUN6V, 0.0f);
  numBytes += cVar_init_f(&cVar_ae0J40th, 0.0f);
  numBytes += cVar_init_f(&cVar_WUgEtXcE, 0.0f);
  numBytes += cVar_init_f(&cVar_Jr6mWUTQ, 0.0f);
  numBytes += cVar_init_f(&cVar_GVMs4v4t, 0.0f);
  numBytes += cVar_init_f(&cVar_kvbkU1Ky, 0.0f);
  numBytes += cVar_init_f(&cVar_dC9UnAXF, 0.0f);
  numBytes += cVar_init_f(&cVar_BZ4XPGa7, 0.0f);
  numBytes += cVar_init_f(&cVar_zta7rJxS, 0.0f);
  numBytes += cVar_init_f(&cVar_zcowAZqI, 0.0f);
  numBytes += cVar_init_f(&cVar_fuoA6XHi, 0.0f);
  numBytes += cVar_init_s(&cVar_bydYGpMA, "del-1348-flanger-l");
  numBytes += sVarf_init(&sVarf_qRiHwXkq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FtK6OlYb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GznrWz29, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_00HrO7Zf, "del-1348-flanger-r");
  numBytes += sVarf_init(&sVarf_ZoiTSAtY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MgzHn8aG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vQLKN5WR, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_xWsqI3xQ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_3gGFpiT3, 0.0f);
  numBytes += hTable_init(&hTable_yqMtosOF, 256);
  numBytes += cDelay_init(this, &cDelay_66Z2pg7I, 0.0f);
  numBytes += cDelay_init(this, &cDelay_PvauYTdd, 0.0f);
  numBytes += hTable_init(&hTable_cA5rHVGy, 256);
  numBytes += cVar_init_f(&cVar_ytZSxJf3, 14.0f);
  numBytes += cBinop_init(&cBinop_iSoGKR7l, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_8cQ0Z1SL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_B6wMxdw2, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_RlWmaYsQ, 14.0f);
  numBytes += cBinop_init(&cBinop_OSjq60jv, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_E8GEDKxl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9V1erVNx, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_rvLO13vB, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_dAdfopJ2, 1, -1);
  numBytes += cVar_init_f(&cVar_3iJk0VsI, 0.2f);
  numBytes += cSlice_init(&cSlice_Qz5bT7ZJ, 1, -1);
  numBytes += cVar_init_f(&cVar_Ll1qvABW, 0.0f);
  numBytes += cSlice_init(&cSlice_Da91M7WI, 1, -1);
  numBytes += cVar_init_f(&cVar_DJz112Ky, 2.0f);
  numBytes += cSlice_init(&cSlice_T1LzUh28, 1, -1);
  numBytes += cVar_init_f(&cVar_DGn0Kp7y, 0.5f);
  numBytes += cVar_init_s(&cVar_uCklAfr1, "del-1397-flanger-l");
  numBytes += sVarf_init(&sVarf_TOdcFi3O, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LoWaK0qK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RzM33K7i, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_4NMyQRgF, "del-1397-flanger-r");
  numBytes += sVarf_init(&sVarf_OTBuV27I, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jQCZc222, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_do2dLbHW, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_0JrHzV5G, 0.0f);
  numBytes += cDelay_init(this, &cDelay_u8me2fd4, 0.0f);
  numBytes += hTable_init(&hTable_uKorntAo, 256);
  numBytes += cDelay_init(this, &cDelay_XL20srPa, 0.0f);
  numBytes += cDelay_init(this, &cDelay_w7O8ErbI, 0.0f);
  numBytes += hTable_init(&hTable_OQxq8Ffk, 256);
  numBytes += cVar_init_f(&cVar_XojjstJD, 14.0f);
  numBytes += cBinop_init(&cBinop_YlHrAcd8, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_0DRmFUUG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XpCqdZun, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Z23cSxQP, 14.0f);
  numBytes += cBinop_init(&cBinop_6I5NfusO, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_zZwGYQV7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UYWVKOTx, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_QqEcsYLT, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_mgBV9XZB, 1, -1);
  numBytes += cVar_init_f(&cVar_cR1rlkcN, 0.2f);
  numBytes += cSlice_init(&cSlice_3bDrqM6P, 1, -1);
  numBytes += cVar_init_f(&cVar_jGLVSL5u, 0.0f);
  numBytes += cSlice_init(&cSlice_sBZNdjWc, 1, -1);
  numBytes += cVar_init_f(&cVar_R2BwKhu3, 2.0f);
  numBytes += cSlice_init(&cSlice_ckWyPnJY, 1, -1);
  numBytes += cVar_init_f(&cVar_hR5AHuFY, 0.5f);
  numBytes += cVar_init_s(&cVar_WYHcJeTW, "del-1446-flanger-l");
  numBytes += sVarf_init(&sVarf_kbv6M6CY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GdUE3vsn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6MDJQqru, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_Jz76m2ot, "del-1446-flanger-r");
  numBytes += sVarf_init(&sVarf_wvsh1eQs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qWp3pLq2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3Hxo7URY, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_zGbFcZ1n, 0.0f);
  numBytes += cDelay_init(this, &cDelay_31ftR8ob, 0.0f);
  numBytes += hTable_init(&hTable_esHiXFKQ, 256);
  numBytes += cDelay_init(this, &cDelay_5CWPZ3RV, 0.0f);
  numBytes += cDelay_init(this, &cDelay_EQH2RqTw, 0.0f);
  numBytes += hTable_init(&hTable_J4RDg2Sc, 256);
  numBytes += cVar_init_f(&cVar_5et4EJcH, 14.0f);
  numBytes += cBinop_init(&cBinop_20QW4pWF, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_X9pDy92m, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_exHquYAF, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_jB8jqRXd, 14.0f);
  numBytes += cBinop_init(&cBinop_kWjl9P9p, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_EvQpJptB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_s3mBbyJc, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_zYlx6IZE, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_SEZrFlsX, 1, -1);
  numBytes += cVar_init_f(&cVar_6uIGnpA3, 0.2f);
  numBytes += cSlice_init(&cSlice_rPsHwubX, 1, -1);
  numBytes += cVar_init_f(&cVar_3qbsQPtS, 0.0f);
  numBytes += cSlice_init(&cSlice_s3FZP5we, 1, -1);
  numBytes += cVar_init_f(&cVar_mwxD98dX, 2.0f);
  numBytes += cSlice_init(&cSlice_SrBjvUhL, 1, -1);
  numBytes += cVar_init_f(&cVar_k16CXNHw, 0.5f);
  numBytes += sVarf_init(&sVarf_2PCdYxMN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SI0JXkSb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Zy9O71ID, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EogjcYx1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_H9CV4BPL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IZjWjPTN, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FL3NGR::~Heavy_WSTD_FL3NGR() {
  hTable_free(&hTable_yqMtosOF);
  hTable_free(&hTable_cA5rHVGy);
  hTable_free(&hTable_uKorntAo);
  hTable_free(&hTable_OQxq8Ffk);
  hTable_free(&hTable_esHiXFKQ);
  hTable_free(&hTable_J4RDg2Sc);
}

HvTable *Heavy_WSTD_FL3NGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x7E84AE7C: return &hTable_yqMtosOF; // del-1348-flanger-r
    case 0x8BC7EF65: return &hTable_cA5rHVGy; // del-1348-flanger-l
    case 0x67C454D4: return &hTable_uKorntAo; // del-1397-flanger-r
    case 0x578173CB: return &hTable_OQxq8Ffk; // del-1397-flanger-l
    case 0xB5F31EFF: return &hTable_esHiXFKQ; // del-1446-flanger-r
    case 0xFB92DE56: return &hTable_J4RDg2Sc; // del-1446-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FL3NGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_izEwVxrI_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ODi7okHf_sendMessage);
      break;
    }
    case 0xA66E154B: { // High_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LHSQgGOg_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TimPVNEG_sendMessage);
      break;
    }
    case 0x49068FB0: { // High_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bykNCjpw_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_feN3IS4B_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PIc1Db9j_sendMessage);
      break;
    }
    case 0xF8FE7D54: { // Low_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CTw6QVnK_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RaeRpQo0_sendMessage);
      break;
    }
    case 0x768962E9: { // Low_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3diylgP5_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_b1RiTSrz_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rtSMb2xe_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tFkYaBXj_sendMessage);
      break;
    }
    case 0x30AE5EFB: { // Mid_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XvepOB2B_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0zKbPPxw_sendMessage);
      break;
    }
    case 0x78CC8F6D: { // Mid_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_plpcXgdV_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_l7FSz5hg_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_l09rkrRG_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bolGImOX_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mnoWQ4Fl_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_re0pWw3V_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ulzhlo5a_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ayIas8Mu_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_deK811wD_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_U6BzHMbx_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2x4gfkcO_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Li6dJvbz_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_a8Eg38YJ_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_w4241gNC_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bNl79CWk_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_slWTKAzs_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yelYJoxi_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_965Z5LKp_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2dc2MOpC_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CfgmlheR_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vvUnd7o0_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ngjt9Jt4_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FIuJl2vN_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7y9lfVAh_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_02tLTmgR_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tvIjN2nJ_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3Ne7bMJh_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QHO4BUrP_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Mc5Fw526_sendMessage);
      break;
    }
    case 0xB9261D01: { // 1348-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8gbXe7aW_sendMessage);
      break;
    }
    case 0x7B4AB7DC: { // 1348-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0EfJJvZs_sendMessage);
      break;
    }
    case 0xC21D5730: { // 1348-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eJLJlvFx_sendMessage);
      break;
    }
    case 0x73E3A43F: { // 1348-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_b655zMxW_sendMessage);
      break;
    }
    case 0x8020E246: { // 1397-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_g1Y5Rs2e_sendMessage);
      break;
    }
    case 0xDE6EF86C: { // 1397-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Y2s1PKE8_sendMessage);
      break;
    }
    case 0x4C9CDCA8: { // 1397-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9yeFwqTS_sendMessage);
      break;
    }
    case 0xB69DF8D2: { // 1397-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_auf4mN6V_sendMessage);
      break;
    }
    case 0x2ABB5D7C: { // 1446-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1E7GnJOs_sendMessage);
      break;
    }
    case 0xE9A86FE0: { // 1446-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_K6dFJk6p_sendMessage);
      break;
    }
    case 0xC66A3021: { // 1446-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BtN6YpIG_sendMessage);
      break;
    }
    case 0x64835C2: { // 1446-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_e6NHv0Hi_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HDFVhTl6_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FL3NGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "High_Intensity";
        info->hash = 0xA66E154B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Speed";
        info->hash = 0x49068FB0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 5: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 7: {
        info->name = "Low_Intensity";
        info->hash = 0xF8FE7D54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 8: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 9: {
        info->name = "Low_Speed";
        info->hash = 0x768962E9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 10: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 13: {
        info->name = "Mid_Intensity";
        info->hash = 0x30AE5EFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 14: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Speed";
        info->hash = 0x78CC8F6D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 16;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FL3NGR::cVar_oz7C4UyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QD3HxASa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ldEwEk0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1HtseAzW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_cFNayMOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MuJQRIyN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_uHLQXCqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lD9Gmt92_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_smi7V09g_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eAVwyGgU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bVIYhssp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_H3pjjdpn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_oD13NZnT, 0, m, &cSlice_oD13NZnT_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Hdnmlnvm_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_oD13NZnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3s80QEPe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3s80QEPe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_iMdy0TWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3s80QEPe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_3s80QEPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bolGImOX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_cUc0cRCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RprgiHGr_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_3CD7GzW3, 0, m, &cIf_3CD7GzW3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_3CD7GzW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_oWhFytSL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_OnORbVOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_HpLs1SZp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_MYvQEiRY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_TP0jnayK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ENax6zPm, HV_BINOP_POW, 0, m, &cBinop_ENax6zPm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ENax6zPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aHrGOSk7, 0, m, &cIf_aHrGOSk7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TgfNfF5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Ity9aIsj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XmaWW4UN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OnORbVOz, 0, m, &cIf_OnORbVOz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_YskBqq2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_575zG7wN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_575zG7wN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OnORbVOz, 1, m, &cIf_OnORbVOz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MYvQEiRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_TgfNfF5i_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_HpLs1SZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_aHrGOSk7, 0, m, &cIf_aHrGOSk7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ity9aIsj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ENax6zPm, HV_BINOP_POW, 1, m, &cBinop_ENax6zPm_sendMessage);
  cMsg_TP0jnayK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_aHrGOSk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_9tooU4Uk, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_RprgiHGr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3CD7GzW3, 1, m, &cIf_3CD7GzW3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oWhFytSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YdMO6yLq, HV_BINOP_GREATER_THAN, 1, m, &cBinop_YdMO6yLq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rACyRTbW, HV_BINOP_EQ, 1, m, &cBinop_rACyRTbW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_q7QyIq3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HhiBxHeD, HV_BINOP_ADD, 0, m, &cBinop_HhiBxHeD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HhiBxHeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YskBqq2w_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XmaWW4UN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YdMO6yLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aHrGOSk7, 1, m, &cIf_aHrGOSk7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rACyRTbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XrehCzia_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_XrehCzia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_9tooU4Uk, m);
}

void Heavy_WSTD_FL3NGR::cCast_JyPucR74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q7QyIq3Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_0muHKbfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HhiBxHeD, HV_BINOP_ADD, 1, m, &cBinop_HhiBxHeD_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YdMO6yLq, HV_BINOP_GREATER_THAN, 0, m, &cBinop_YdMO6yLq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rACyRTbW, HV_BINOP_EQ, 0, m, &cBinop_rACyRTbW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0QQyYumq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cUc0cRCh, 0, m, &cVar_cUc0cRCh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_xBwCBx3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_TycVP3Jr_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_D21VapRk, 0, m, &cIf_D21VapRk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_D21VapRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xvI1Q3md_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_M1C5PvSh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_EUyXOo6e_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_yIhNmYOA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_XmtMVyZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ad7dlIO2, HV_BINOP_POW, 0, m, &cBinop_ad7dlIO2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ad7dlIO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ynzp2oup, 0, m, &cIf_ynzp2oup_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QLTBiw2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_oj9TznQb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hzyVwOH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M1C5PvSh, 0, m, &cIf_M1C5PvSh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_N3PElaZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_t07PzxaV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_t07PzxaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M1C5PvSh, 1, m, &cIf_M1C5PvSh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yIhNmYOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_QLTBiw2c_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_EUyXOo6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ynzp2oup, 0, m, &cIf_ynzp2oup_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oj9TznQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ad7dlIO2, HV_BINOP_POW, 1, m, &cBinop_ad7dlIO2_sendMessage);
  cMsg_XmtMVyZm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_ynzp2oup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_fNggSFck_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ae3fk0zr_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Tx919EpQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_TycVP3Jr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D21VapRk, 1, m, &cIf_D21VapRk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xvI1Q3md_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DRjO5N1y, HV_BINOP_GREATER_THAN, 1, m, &cBinop_DRjO5N1y_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yO54bVCz, HV_BINOP_EQ, 1, m, &cBinop_yO54bVCz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ztE33vQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SoXvGsOT, HV_BINOP_ADD, 0, m, &cBinop_SoXvGsOT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SoXvGsOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N3PElaZ7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hzyVwOH0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DRjO5N1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ynzp2oup, 1, m, &cIf_ynzp2oup_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yO54bVCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aREePeXr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_aREePeXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_fNggSFck_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ae3fk0zr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Tx919EpQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_QniJ4K2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xBwCBx3o, 0, m, &cVar_xBwCBx3o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GZYWmXiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ztE33vQ9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_U6daj67v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SoXvGsOT, HV_BINOP_ADD, 1, m, &cBinop_SoXvGsOT_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DRjO5N1y, HV_BINOP_GREATER_THAN, 0, m, &cBinop_DRjO5N1y_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yO54bVCz, HV_BINOP_EQ, 0, m, &cBinop_yO54bVCz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_iUm41Ccy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0NwM6LPA_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_7tJ7gj5M, 0, m, &cIf_7tJ7gj5M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_7tJ7gj5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8W15xfX6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_IUHp6MbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_8bOgotbt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_FCl5pHSY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_M8im6B1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rh7SrqIY, HV_BINOP_POW, 0, m, &cBinop_rh7SrqIY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rh7SrqIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vMlWDihI, 0, m, &cIf_vMlWDihI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_geljqOZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_CUQKMHiT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fRVA313J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZzLFc7tv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Iw0NfUge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IUHp6MbU, 0, m, &cIf_IUHp6MbU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZzLFc7tv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IUHp6MbU, 1, m, &cIf_IUHp6MbU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FCl5pHSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_geljqOZJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_8bOgotbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_vMlWDihI, 0, m, &cIf_vMlWDihI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CUQKMHiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rh7SrqIY, HV_BINOP_POW, 1, m, &cBinop_rh7SrqIY_sendMessage);
  cMsg_M8im6B1n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_vMlWDihI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_BF8IelrZ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_0NwM6LPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7tJ7gj5M, 1, m, &cIf_7tJ7gj5M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8W15xfX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6qfgeMFy, HV_BINOP_GREATER_THAN, 1, m, &cBinop_6qfgeMFy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YlKf1nhI, HV_BINOP_EQ, 1, m, &cBinop_YlKf1nhI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_dBIZuyRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FIBoWOEZ, HV_BINOP_ADD, 0, m, &cBinop_FIBoWOEZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FIBoWOEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fRVA313J_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Iw0NfUge_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6qfgeMFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vMlWDihI, 1, m, &cIf_vMlWDihI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YlKf1nhI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YxObp0vJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_YxObp0vJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BF8IelrZ, m);
}

void Heavy_WSTD_FL3NGR::cCast_XxiAJj9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dBIZuyRz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_8xylhMks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FIBoWOEZ, HV_BINOP_ADD, 1, m, &cBinop_FIBoWOEZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6qfgeMFy, HV_BINOP_GREATER_THAN, 0, m, &cBinop_6qfgeMFy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YlKf1nhI, HV_BINOP_EQ, 0, m, &cBinop_YlKf1nhI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_E6U8Qk8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iUm41Ccy, 0, m, &cVar_iUm41Ccy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_h3q0aBMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_iNCmDaUN, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_SsD8oXmt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_oy5mgFBF, 0, m, &cSlice_oy5mgFBF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_RnzXDHji_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_oy5mgFBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cDZKh3RK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cDZKh3RK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_xEY5fKVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cDZKh3RK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_cDZKh3RK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_l7FSz5hg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_RnzXDHji_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_v91JVVQF, 0, m, &cSlice_v91JVVQF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_H3pjjdpn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_v91JVVQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DB7mwi7i_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DB7mwi7i_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_VVlbafAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DB7mwi7i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_DB7mwi7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_re0pWw3V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Hdnmlnvm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_p3qgN0UC, 0, m, &cSlice_p3qgN0UC_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3CE5lv6A_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_p3qgN0UC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_toEzO5jy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_toEzO5jy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_7EFwl6WE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_toEzO5jy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_toEzO5jy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_l09rkrRG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_3CE5lv6A_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HBjbMSmS, 0, m, &cSlice_HBjbMSmS_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_HBjbMSmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LaTQAQTB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LaTQAQTB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_JEAlLkZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LaTQAQTB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_LaTQAQTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mnoWQ4Fl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_62cGjxUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tcqCC40R, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Vs08lviQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7iI2FIwz, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_YogIXf0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kcBju681, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_zGf7G7iL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rEHoyQz2, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_isnLFKyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JXeZvpQL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_hObSl0Ti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YaTGs9vs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_YaTGs9vs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XnhoRMho, HV_BINOP_DIVIDE, 1, m, &cBinop_XnhoRMho_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0KGybq6p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_r0t1bQo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_9pw6GtkK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_h3qDXy3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_r0t1bQo5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9pw6GtkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XnhoRMho, HV_BINOP_DIVIDE, 0, m, &cBinop_XnhoRMho_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0KGybq6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h3qDXy3N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XnhoRMho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BvTywMKd, HV_BINOP_MULTIPLY, 1, m, &cBinop_BvTywMKd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BvTywMKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s99fq2F4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oAgTQ602_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_pWtxjoqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4vliyqU9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_hJY4PKjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_umo75S3r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_iThagvJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_g8ESZ4MI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_g8ESZ4MI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BvTywMKd, HV_BINOP_MULTIPLY, 0, m, &cBinop_BvTywMKd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ENUDEkUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_sDXJddWb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sDXJddWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_05jePFGH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_X0EoASog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7ljVfgM5, 1, m, &cVar_7ljVfgM5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_7ljVfgM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PuntPhfX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_HZDPOk69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JQJi4G1o, HV_BINOP_MULTIPLY, 1, m, &cBinop_JQJi4G1o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RYBOdq2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HZDPOk69_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4FBFRBBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_mK6gZGtk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mK6gZGtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DKlBjMW2, HV_BINOP_MULTIPLY, 1, m, &cBinop_DKlBjMW2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bhxSVNNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8kR9v5Xf, HV_BINOP_MULTIPLY, 1, m, &cBinop_8kR9v5Xf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_h4GrElv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_bhxSVNNY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AQa11xgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nmbJccHk, HV_BINOP_MULTIPLY, 1, m, &cBinop_nmbJccHk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_F4Iu8y6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_33Jy4dR2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_33Jy4dR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XyUHIQni, HV_BINOP_MULTIPLY, 1, m, &cBinop_XyUHIQni_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_AnZbbXRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KaW1Bhaw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_iThagvJt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JgVmBQG4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_NjaQXfbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ENUDEkUy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_oAgTQ602_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_hJY4PKjn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_s99fq2F4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_pWtxjoqf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_4vliyqU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_deK811wD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_umo75S3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ayIas8Mu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_f70RkMRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ulzhlo5a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_05jePFGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_DZ7CZMa2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DZ7CZMa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nhvgmdwr, HV_BINOP_MULTIPLY, 1, m, &cBinop_Nhvgmdwr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Nhvgmdwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2qlG8Exd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2qlG8Exd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f70RkMRc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_PuntPhfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_fXLkokAw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fXLkokAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TCn8qt5s_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MhSuL2Xz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jClcjqZI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cGijQcsA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3GiyvqqV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VYgvDwtl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JQJi4G1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_62cGjxUw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_DKlBjMW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vs08lviQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_8kR9v5Xf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YogIXf0V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nmbJccHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zGf7G7iL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XyUHIQni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_isnLFKyG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_gJbaknAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AnZbbXRp, 0, m, &cVar_AnZbbXRp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0lftlXfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NjaQXfbR, 1, m, &cVar_NjaQXfbR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_VYgvDwtl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JQJi4G1o, HV_BINOP_MULTIPLY, 0, m, &cBinop_JQJi4G1o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jClcjqZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nmbJccHk, HV_BINOP_MULTIPLY, 0, m, &cBinop_nmbJccHk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_cGijQcsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8kR9v5Xf, HV_BINOP_MULTIPLY, 0, m, &cBinop_8kR9v5Xf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MhSuL2Xz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XyUHIQni, HV_BINOP_MULTIPLY, 0, m, &cBinop_XyUHIQni_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TCn8qt5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_3GiyvqqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DKlBjMW2, HV_BINOP_MULTIPLY, 0, m, &cBinop_DKlBjMW2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JgVmBQG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7ljVfgM5, 0, m, &cVar_7ljVfgM5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_KaW1Bhaw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NjaQXfbR, 0, m, &cVar_NjaQXfbR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_vQgUHReV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cTcU1J1G, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_kmpntwKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aToP3TOa, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_71gWtOoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iGlLF8XB, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_FGDFcpyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_y4nENucK, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ibsdLFeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ejTgFs3r_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_ejTgFs3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cdHzXtND, HV_BINOP_DIVIDE, 1, m, &cBinop_cdHzXtND_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bt3MLgP4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_DShmNSPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_d5SgshRN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_vGdQ86Gi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_DShmNSPg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_d5SgshRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cdHzXtND, HV_BINOP_DIVIDE, 0, m, &cBinop_cdHzXtND_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Bt3MLgP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vGdQ86Gi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_cdHzXtND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wq2qf5Oy, HV_BINOP_MULTIPLY, 1, m, &cBinop_Wq2qf5Oy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Wq2qf5Oy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CUJW0rLk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2imCIaSw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_8AamvwGe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HoixIJRr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_Dj9X9AH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zhaoSyZc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ZvqW2rmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_D51kWhgR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_D51kWhgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wq2qf5Oy, HV_BINOP_MULTIPLY, 0, m, &cBinop_Wq2qf5Oy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RNkncCre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_6O5luJuU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6O5luJuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_49m2p4uX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_mAwaSdEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EA2lhL31, HV_BINOP_MULTIPLY, 1, m, &cBinop_EA2lhL31_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WvpoA00A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9JwHs3hy, 1, m, &cVar_9JwHs3hy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ayG3TiOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xZrvamYi, HV_BINOP_MULTIPLY, 1, m, &cBinop_xZrvamYi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_CTrpwVEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nj4ndkjQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nj4ndkjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ko1rGWQz, HV_BINOP_MULTIPLY, 1, m, &cBinop_ko1rGWQz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_9JwHs3hy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zIoFE6EL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_M7UNEPrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a4iTzsXx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ZvqW2rmC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J4JJJtJj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_csVitYPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_RNkncCre_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_2imCIaSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_Dj9X9AH8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CUJW0rLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_8AamvwGe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_HoixIJRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Li6dJvbz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_zhaoSyZc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2x4gfkcO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_ua7smT9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_U6BzHMbx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_49m2p4uX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_xEibQh9M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xEibQh9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uRZJ7YrB, HV_BINOP_MULTIPLY, 1, m, &cBinop_uRZJ7YrB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uRZJ7YrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uqET9mCg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uqET9mCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ua7smT9B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_zIoFE6EL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_d9GhGJJw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_d9GhGJJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bd77tXjc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RikFHCUC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AooLoJ7Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7OQS9Dfn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XUyecwPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vQgUHReV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_EA2lhL31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kmpntwKD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_xZrvamYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_71gWtOoS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ko1rGWQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FGDFcpyp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_Px8C1wBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M7UNEPrf, 0, m, &cVar_M7UNEPrf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pl4KSR7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_csVitYPN, 1, m, &cVar_csVitYPN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_J4JJJtJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9JwHs3hy, 0, m, &cVar_9JwHs3hy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_a4iTzsXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_csVitYPN, 0, m, &cVar_csVitYPN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Bd77tXjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ko1rGWQz, HV_BINOP_MULTIPLY, 0, m, &cBinop_ko1rGWQz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7OQS9Dfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XUyecwPP, HV_BINOP_MULTIPLY, 0, m, &cBinop_XUyecwPP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_AooLoJ7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EA2lhL31, HV_BINOP_MULTIPLY, 0, m, &cBinop_EA2lhL31_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_RikFHCUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xZrvamYi, HV_BINOP_MULTIPLY, 0, m, &cBinop_xZrvamYi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_VC25wlGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fp0Wa5tk, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_7cdKx8iW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_x8nV1y5C, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_RzFg0K8D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rFtgVc5Y, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_GLRkX1PM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2rbWQfBq, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_r1B3RdTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_i8mIQpUl, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_hXtQo94o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_A6w1KiP7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_A6w1KiP7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RMjXyed9, HV_BINOP_DIVIDE, 1, m, &cBinop_RMjXyed9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yidJjC3w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_eVQ80D09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Tny8wYbh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_QOBvw6un_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_eVQ80D09_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Tny8wYbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RMjXyed9, HV_BINOP_DIVIDE, 0, m, &cBinop_RMjXyed9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yidJjC3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QOBvw6un_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_RMjXyed9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dJsg2Vpv, HV_BINOP_MULTIPLY, 1, m, &cBinop_dJsg2Vpv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dJsg2Vpv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K8Mf3ybP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Sw6IajyS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_QlWfYfde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ToLkhyGu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_iyH3cr0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_n91cV7dN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_C8lVEfSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_gQg2N1oe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gQg2N1oe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dJsg2Vpv, HV_BINOP_MULTIPLY, 0, m, &cBinop_dJsg2Vpv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fgcw9ybg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_q7Exsdim_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_q7Exsdim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Nzg7hHej_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_5290CYFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HzLOiJ90, HV_BINOP_MULTIPLY, 1, m, &cBinop_HzLOiJ90_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_08q7LWnG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_dV8LqaZX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dV8LqaZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5290CYFp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_C8E4q7UQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_PrU6FXXh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PrU6FXXh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hms15U2w, HV_BINOP_MULTIPLY, 1, m, &cBinop_Hms15U2w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_38wHv529_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_doEiW49l, HV_BINOP_MULTIPLY, 1, m, &cBinop_doEiW49l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_J6yAstV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_djNJlTpI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_djNJlTpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_38wHv529_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_paPDPmVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9cNPZkHv, 1, m, &cVar_9cNPZkHv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PqfemkPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_agqriNwf, HV_BINOP_MULTIPLY, 1, m, &cBinop_agqriNwf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4EzVXu4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_71ajz6oc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_71ajz6oc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ogJtDv5C, HV_BINOP_MULTIPLY, 1, m, &cBinop_ogJtDv5C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_9cNPZkHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7tFHRSsg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_4BD9Jdp2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rUt8bqig_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_C8lVEfSP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sEKKHeh4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_0ddChBYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_fgcw9ybg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_K8Mf3ybP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_QlWfYfde_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Sw6IajyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_iyH3cr0D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_ToLkhyGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bNl79CWk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_n91cV7dN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_w4241gNC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Iqo2hZfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_a8Eg38YJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Nzg7hHej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_c2vuMcRx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_c2vuMcRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iDZIJop5, HV_BINOP_MULTIPLY, 1, m, &cBinop_iDZIJop5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iDZIJop5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kyGvKiTI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kyGvKiTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Iqo2hZfi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_7tFHRSsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_iOsMf8cI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iOsMf8cI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7rlvnBlH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NQ5D6rWn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Rq1imm0u_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FdwOd5W4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g3TnSdrS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q4dZ5MfR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HzLOiJ90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VC25wlGa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Hms15U2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7cdKx8iW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_doEiW49l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RzFg0K8D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_agqriNwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GLRkX1PM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ogJtDv5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r1B3RdTq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_hDwpbzMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0ddChBYI, 1, m, &cVar_0ddChBYI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ELENTJyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4BD9Jdp2, 0, m, &cVar_4BD9Jdp2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Q4dZ5MfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HzLOiJ90, HV_BINOP_MULTIPLY, 0, m, &cBinop_HzLOiJ90_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Rq1imm0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_agqriNwf, HV_BINOP_MULTIPLY, 0, m, &cBinop_agqriNwf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7rlvnBlH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_NQ5D6rWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ogJtDv5C, HV_BINOP_MULTIPLY, 0, m, &cBinop_ogJtDv5C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FdwOd5W4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_doEiW49l, HV_BINOP_MULTIPLY, 0, m, &cBinop_doEiW49l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_g3TnSdrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hms15U2w, HV_BINOP_MULTIPLY, 0, m, &cBinop_Hms15U2w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rUt8bqig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0ddChBYI, 0, m, &cVar_0ddChBYI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sEKKHeh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9cNPZkHv, 0, m, &cVar_9cNPZkHv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fNggSFck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h3q0aBMl, 1, m, &cIf_h3q0aBMl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_okxGxfdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_iNCmDaUN, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ae3fk0zr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_okxGxfdW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Tx919EpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h3q0aBMl, 0, m, &cIf_h3q0aBMl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_mJadti5U_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hBiqHxts, 0, m, &cSlice_hBiqHxts_sendMessage);
      break;
    }
    default: {
      cSwitchcase_beJayPyJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_hBiqHxts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wDlOTYja_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wDlOTYja_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_TJCeWTFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wDlOTYja_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_wDlOTYja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_965Z5LKp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_EjLhABz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_34pCZQFu_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_7DapzRxl, 0, m, &cIf_7DapzRxl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_7DapzRxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_hnhAlLW7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_jwvpT02M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_kiwMqhJB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_JJLXhuhM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_5cADIodt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YZDgqVTW, HV_BINOP_POW, 0, m, &cBinop_YZDgqVTW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YZDgqVTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eQJWDn9J, 0, m, &cIf_eQJWDn9J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AFMmPz6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_uz4UWgxW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_13luPwCp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jwvpT02M, 0, m, &cIf_jwvpT02M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_dg7lurjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VYgfC3PD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VYgfC3PD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jwvpT02M, 1, m, &cIf_jwvpT02M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JJLXhuhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_AFMmPz6s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_kiwMqhJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_eQJWDn9J, 0, m, &cIf_eQJWDn9J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uz4UWgxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YZDgqVTW, HV_BINOP_POW, 1, m, &cBinop_YZDgqVTW_sendMessage);
  cMsg_5cADIodt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_eQJWDn9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_lXIherSm, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_34pCZQFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7DapzRxl, 1, m, &cIf_7DapzRxl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hnhAlLW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hRGHEgwT, HV_BINOP_GREATER_THAN, 1, m, &cBinop_hRGHEgwT_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ebUxfjQe, HV_BINOP_EQ, 1, m, &cBinop_ebUxfjQe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_HXr9AO2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SuhHhsLr, HV_BINOP_ADD, 0, m, &cBinop_SuhHhsLr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SuhHhsLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dg7lurjY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_13luPwCp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hRGHEgwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eQJWDn9J, 1, m, &cIf_eQJWDn9J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ebUxfjQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MK1OHZuL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_MK1OHZuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_lXIherSm, m);
}

void Heavy_WSTD_FL3NGR::cCast_bKmfzh5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EjLhABz0, 0, m, &cVar_EjLhABz0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZrFhIK4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HXr9AO2V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_gIyYMAvc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SuhHhsLr, HV_BINOP_ADD, 1, m, &cBinop_SuhHhsLr_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hRGHEgwT, HV_BINOP_GREATER_THAN, 0, m, &cBinop_hRGHEgwT_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ebUxfjQe, HV_BINOP_EQ, 0, m, &cBinop_ebUxfjQe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_NKDjhzUN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ndg62z5L_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_m9Y1kPMR, 0, m, &cIf_m9Y1kPMR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_m9Y1kPMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_0CQWm6aK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_9QmxgK3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_OVKCh8vr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_1k87ezXg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_FdehXlQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_X6EwV6n9, HV_BINOP_POW, 0, m, &cBinop_X6EwV6n9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_X6EwV6n9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mjuHmkvO, 0, m, &cIf_mjuHmkvO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vMNFc76v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_8w0LszeD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_kqu1odZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_habTwGxm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1wBPVVnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9QmxgK3e, 0, m, &cIf_9QmxgK3e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_habTwGxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9QmxgK3e, 1, m, &cIf_9QmxgK3e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1k87ezXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_vMNFc76v_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OVKCh8vr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_mjuHmkvO, 0, m, &cIf_mjuHmkvO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8w0LszeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X6EwV6n9, HV_BINOP_POW, 1, m, &cBinop_X6EwV6n9_sendMessage);
  cMsg_FdehXlQ0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_mjuHmkvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JjwFvlHb_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2D2MUfF4_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_OzqSDDuH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_ndg62z5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m9Y1kPMR, 1, m, &cIf_m9Y1kPMR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0CQWm6aK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZZqtD6AG, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ZZqtD6AG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SMChB942, HV_BINOP_EQ, 1, m, &cBinop_SMChB942_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_AnSI044D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KWmGuT8x, HV_BINOP_ADD, 0, m, &cBinop_KWmGuT8x_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KWmGuT8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kqu1odZA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1wBPVVnf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZZqtD6AG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mjuHmkvO, 1, m, &cIf_mjuHmkvO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SMChB942_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q5T7KuWj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Q5T7KuWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JjwFvlHb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2D2MUfF4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_OzqSDDuH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_eHgCOpz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KWmGuT8x, HV_BINOP_ADD, 1, m, &cBinop_KWmGuT8x_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZZqtD6AG, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ZZqtD6AG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SMChB942, HV_BINOP_EQ, 0, m, &cBinop_SMChB942_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xPhTY4xy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NKDjhzUN, 0, m, &cVar_NKDjhzUN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_oAv6FF26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AnSI044D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ldGrKpnj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YeMNJn9H_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_5lc0J818, 0, m, &cIf_5lc0J818_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_5lc0J818_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_2oa4yb2R_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_GGwgBBhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_8fu5ZEzS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_v4TcdIKw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_aN6xAMSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VH4CqPsI, HV_BINOP_POW, 0, m, &cBinop_VH4CqPsI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VH4CqPsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_61qkG2zk, 0, m, &cIf_61qkG2zk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BRwpJXMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_XMsunsLE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hXivQRIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CSxPrHAb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5dIeXcNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GGwgBBhK, 0, m, &cIf_GGwgBBhK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CSxPrHAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GGwgBBhK, 1, m, &cIf_GGwgBBhK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_v4TcdIKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_BRwpJXMr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_8fu5ZEzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_61qkG2zk, 0, m, &cIf_61qkG2zk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XMsunsLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VH4CqPsI, HV_BINOP_POW, 1, m, &cBinop_VH4CqPsI_sendMessage);
  cMsg_aN6xAMSF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_61qkG2zk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_LsTXWmrX, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_YeMNJn9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5lc0J818, 1, m, &cIf_5lc0J818_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2oa4yb2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W1ijtJYM, HV_BINOP_GREATER_THAN, 1, m, &cBinop_W1ijtJYM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OtQSdTx2, HV_BINOP_EQ, 1, m, &cBinop_OtQSdTx2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_LdN4kCLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PfawCcOI, HV_BINOP_ADD, 0, m, &cBinop_PfawCcOI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PfawCcOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hXivQRIO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5dIeXcNO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_W1ijtJYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_61qkG2zk, 1, m, &cIf_61qkG2zk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OtQSdTx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rnEF8gYt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_rnEF8gYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_LsTXWmrX, m);
}

void Heavy_WSTD_FL3NGR::cCast_wyBeiXIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LdN4kCLT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_8H8apbNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PfawCcOI, HV_BINOP_ADD, 1, m, &cBinop_PfawCcOI_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_W1ijtJYM, HV_BINOP_GREATER_THAN, 0, m, &cBinop_W1ijtJYM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OtQSdTx2, HV_BINOP_EQ, 0, m, &cBinop_OtQSdTx2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_2ADgg6Q8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ldGrKpnj, 0, m, &cVar_ldGrKpnj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_QzrCEHGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_3clxlTvb, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_cXOjpUZY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vzNEG3O8, 0, m, &cSlice_vzNEG3O8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_c0Zxp76o_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_vzNEG3O8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sTuQizfI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sTuQizfI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_uPwabecF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sTuQizfI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_sTuQizfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_slWTKAzs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_c0Zxp76o_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_toReXj7S, 0, m, &cSlice_toReXj7S_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mJadti5U_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_toReXj7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Wuapwfy2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Wuapwfy2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_8hsryfdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Wuapwfy2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Wuapwfy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CfgmlheR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_beJayPyJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jOvMuZA7, 0, m, &cSlice_jOvMuZA7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Un3HCrLX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_jOvMuZA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4g3ho8OM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4g3ho8OM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_LF44zxdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4g3ho8OM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_4g3ho8OM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yelYJoxi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Un3HCrLX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_QUtnOPma, 0, m, &cSlice_QUtnOPma_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_QUtnOPma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fdhja5Uw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fdhja5Uw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_QqhdjAnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fdhja5Uw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_fdhja5Uw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2dc2MOpC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_hqUUag8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mHiMPZQj, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_IEZEjqLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4d5kDSLq, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ZYZUBrZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J7qbvHRr, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_GeeXdrib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H70voZQM, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_7GcjnsUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_W1FLm0AB, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_2Is0qo6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CKJguEDe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_CKJguEDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eV1oGnzS, HV_BINOP_DIVIDE, 1, m, &cBinop_eV1oGnzS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xnNv9EOt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_6LPOCjnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_GS3FsXdv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wHUV7ByE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_6LPOCjnR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GS3FsXdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eV1oGnzS, HV_BINOP_DIVIDE, 0, m, &cBinop_eV1oGnzS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xnNv9EOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wHUV7ByE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_eV1oGnzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ILh0nrVY, HV_BINOP_MULTIPLY, 1, m, &cBinop_ILh0nrVY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ILh0nrVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VQGvjmNR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hxb0QBqf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_TJERizyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_55rlEoh7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_TXOcnZJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UECz431x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_FRBl9CBc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_jsARcRkh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jsARcRkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ILh0nrVY, HV_BINOP_MULTIPLY, 0, m, &cBinop_ILh0nrVY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oRqOCnSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_JjsDvCNC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JjsDvCNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mpnm2awD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_q59KIdI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yCvmXnrh, 1, m, &cVar_yCvmXnrh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_yCvmXnrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rc7i0VKx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_awZPRxhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jXEEcUT7, HV_BINOP_MULTIPLY, 1, m, &cBinop_jXEEcUT7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Cz7wJuDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_awZPRxhF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XAp0bDUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8Rabs5aC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8Rabs5aC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4dYgFyBt, HV_BINOP_MULTIPLY, 1, m, &cBinop_4dYgFyBt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_d3nXhdqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6t7nT2g2, HV_BINOP_MULTIPLY, 1, m, &cBinop_6t7nT2g2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6oku71uF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_d3nXhdqj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_q7rWNBpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RbrEKLgT, HV_BINOP_MULTIPLY, 1, m, &cBinop_RbrEKLgT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_vOJj7enF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9xRWV7dO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9xRWV7dO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qwm10DbI, HV_BINOP_MULTIPLY, 1, m, &cBinop_qwm10DbI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_bpg6j99l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_08eqHfyj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_FRBl9CBc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iM5i5pCY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_7U4d34AQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_oRqOCnSp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_VQGvjmNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_TJERizyd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Hxb0QBqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_TXOcnZJJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_55rlEoh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FIuJl2vN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_UECz431x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ngjt9Jt4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_hkTuDcmY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vvUnd7o0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_mpnm2awD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qO1rLQtd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qO1rLQtd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sPsrBRKy, HV_BINOP_MULTIPLY, 1, m, &cBinop_sPsrBRKy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sPsrBRKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cDIdivzx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cDIdivzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hkTuDcmY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_rc7i0VKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6fiPTyDC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6fiPTyDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_B7Nd2r1U_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PwgVXWjC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xVXnnsUX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RbSZaXui_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Sli0zRgI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YFIQQkY0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jXEEcUT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hqUUag8l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_4dYgFyBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IEZEjqLe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_6t7nT2g2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZYZUBrZJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_RbrEKLgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GeeXdrib_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qwm10DbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7GcjnsUs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_3lysvPLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bpg6j99l, 0, m, &cVar_bpg6j99l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_qGc0cHue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7U4d34AQ, 1, m, &cVar_7U4d34AQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PwgVXWjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qwm10DbI, HV_BINOP_MULTIPLY, 0, m, &cBinop_qwm10DbI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_RbSZaXui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6t7nT2g2, HV_BINOP_MULTIPLY, 0, m, &cBinop_6t7nT2g2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_YFIQQkY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jXEEcUT7, HV_BINOP_MULTIPLY, 0, m, &cBinop_jXEEcUT7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_B7Nd2r1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_xVXnnsUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RbrEKLgT, HV_BINOP_MULTIPLY, 0, m, &cBinop_RbrEKLgT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Sli0zRgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4dYgFyBt, HV_BINOP_MULTIPLY, 0, m, &cBinop_4dYgFyBt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iM5i5pCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yCvmXnrh, 0, m, &cVar_yCvmXnrh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_08eqHfyj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7U4d34AQ, 0, m, &cVar_7U4d34AQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_zn6xuvqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9zAbs7dz, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_RuaielGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RYEYNDiy, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Pm8Wg8LB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XRh2uJVw, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Uq0bPBqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UApHMuFn, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_I5kCuagl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_I4ZlnuT2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_I4ZlnuT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9gFKS1lc, HV_BINOP_DIVIDE, 1, m, &cBinop_9gFKS1lc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uU89GAzh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_Tj7w9EwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_0odWfIfr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5ZSxcIph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Tj7w9EwI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0odWfIfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9gFKS1lc, HV_BINOP_DIVIDE, 0, m, &cBinop_9gFKS1lc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_uU89GAzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5ZSxcIph_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_9gFKS1lc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fU2OpwG7, HV_BINOP_MULTIPLY, 1, m, &cBinop_fU2OpwG7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fU2OpwG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qlkd58YA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3YWx8TJv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_NVOhHCA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_b7fEvgZP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_Kd0mt3nv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iPgILwzG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_TTi7PVHr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_EtJQs7YY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EtJQs7YY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fU2OpwG7, HV_BINOP_MULTIPLY, 0, m, &cBinop_fU2OpwG7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wtVB2YYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_u6SiuRtx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_u6SiuRtx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MoMLyZpY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UzQ8wubl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3ZpQIYDq, HV_BINOP_MULTIPLY, 1, m, &cBinop_3ZpQIYDq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UzE937Kz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xKQaudQA, 1, m, &cVar_xKQaudQA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8A1KFzqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r1TxioJx, HV_BINOP_MULTIPLY, 1, m, &cBinop_r1TxioJx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_9sZnhhMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_TivzCYoq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TivzCYoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DeRF12Ae, HV_BINOP_MULTIPLY, 1, m, &cBinop_DeRF12Ae_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_xKQaudQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K0iDxW26_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_uxNTZpqS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oStesqc9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_TTi7PVHr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QSdfxUGO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_OPyZCddF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_wtVB2YYH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3YWx8TJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_Kd0mt3nv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_qlkd58YA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_NVOhHCA6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_b7fEvgZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tvIjN2nJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_iPgILwzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_02tLTmgR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_7UZR6F0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7y9lfVAh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_MoMLyZpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_mvs5P8Fu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mvs5P8Fu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nth0L5us, HV_BINOP_MULTIPLY, 1, m, &cBinop_nth0L5us_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nth0L5us_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_UeYAmRO3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UeYAmRO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7UZR6F0r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_K0iDxW26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qYmIlKCl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qYmIlKCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4yqnfqaz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CrFFUVhR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TWVwm0Vc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mTzJKg1y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_w6vMObcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zn6xuvqo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_3ZpQIYDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RuaielGS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_r1TxioJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Pm8Wg8LB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_DeRF12Ae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Uq0bPBqY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_ny1eLUmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uxNTZpqS, 0, m, &cVar_uxNTZpqS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_teqAtCPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OPyZCddF, 1, m, &cVar_OPyZCddF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_QSdfxUGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xKQaudQA, 0, m, &cVar_xKQaudQA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_oStesqc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OPyZCddF, 0, m, &cVar_OPyZCddF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mTzJKg1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w6vMObcW, HV_BINOP_MULTIPLY, 0, m, &cBinop_w6vMObcW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TWVwm0Vc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3ZpQIYDq, HV_BINOP_MULTIPLY, 0, m, &cBinop_3ZpQIYDq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CrFFUVhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r1TxioJx, HV_BINOP_MULTIPLY, 0, m, &cBinop_r1TxioJx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4yqnfqaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DeRF12Ae, HV_BINOP_MULTIPLY, 0, m, &cBinop_DeRF12Ae_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wjK33hBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QDFw4tkg, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_a8bpDAYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lNlcjPvE, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_8EAJO8Re_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_m2FqzZdX, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_0IogSNxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RVr9glzQ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_v6MwplPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_g6eCNDUT, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_AeR2A8ri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bBMFJc49_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_bBMFJc49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I1d800Qr, HV_BINOP_DIVIDE, 1, m, &cBinop_I1d800Qr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YKYVotJ8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_iw4r9Pah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_1XOhhSMZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_UGPTCMrK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_iw4r9Pah_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1XOhhSMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I1d800Qr, HV_BINOP_DIVIDE, 0, m, &cBinop_I1d800Qr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_YKYVotJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UGPTCMrK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_I1d800Qr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QsX98j3p, HV_BINOP_MULTIPLY, 1, m, &cBinop_QsX98j3p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QsX98j3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zu4lQv6E_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PjT3l9S1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_qRrjSszw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hJINaP24_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_vpar3uCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cDmQwERy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_DSkEeoUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_0pHFCT8u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0pHFCT8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QsX98j3p, HV_BINOP_MULTIPLY, 0, m, &cBinop_QsX98j3p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pFHhxF9L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_OTXMqSj2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OTXMqSj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TweY0hsD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_dygnSFWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KwGIderH, HV_BINOP_MULTIPLY, 1, m, &cBinop_KwGIderH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0f1xYyDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7oxRuwut_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7oxRuwut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_dygnSFWB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ORToJQls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_RoEqKVb6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RoEqKVb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MAOrSjnr, HV_BINOP_MULTIPLY, 1, m, &cBinop_MAOrSjnr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XBjXQy8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WPijBM2X, HV_BINOP_MULTIPLY, 1, m, &cBinop_WPijBM2X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_O6oAZfbF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_SGTleSa8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SGTleSa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_XBjXQy8t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eJ0TtcuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oJCtGmUB, 1, m, &cVar_oJCtGmUB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_N9LAkCJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vS2c8OVf, HV_BINOP_MULTIPLY, 1, m, &cBinop_vS2c8OVf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2seDt9Mb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_szhyn970_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_szhyn970_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fE5A4TxA, HV_BINOP_MULTIPLY, 1, m, &cBinop_fE5A4TxA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_oJCtGmUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZJfm8FvH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_RPOUuqrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GP3f1S7k_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_DSkEeoUW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oUGJ0LEN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_tgYa4xj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_pFHhxF9L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PjT3l9S1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_vpar3uCU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zu4lQv6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_qRrjSszw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_hJINaP24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Mc5Fw526_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_cDmQwERy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QHO4BUrP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_hp7GP4up_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3Ne7bMJh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_TweY0hsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Q6lb8UrI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Q6lb8UrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a3CzXAXe, HV_BINOP_MULTIPLY, 1, m, &cBinop_a3CzXAXe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_a3CzXAXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3ne4p5dv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3ne4p5dv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hp7GP4up_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ZJfm8FvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_k8hjJK7O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_k8hjJK7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A1PLuPf0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6ySaAA7F_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vHZR4cfb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CF7IrD3x_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_egxhDQiI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fl74nscx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KwGIderH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wjK33hBu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_MAOrSjnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a8bpDAYx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_WPijBM2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8EAJO8Re_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vS2c8OVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0IogSNxh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_fE5A4TxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v6MwplPX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_BYqYjYUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RPOUuqrI, 0, m, &cVar_RPOUuqrI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_kHqF9mQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tgYa4xj5, 1, m, &cVar_tgYa4xj5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vHZR4cfb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vS2c8OVf, HV_BINOP_MULTIPLY, 0, m, &cBinop_vS2c8OVf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6ySaAA7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fE5A4TxA, HV_BINOP_MULTIPLY, 0, m, &cBinop_fE5A4TxA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CF7IrD3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WPijBM2X, HV_BINOP_MULTIPLY, 0, m, &cBinop_WPijBM2X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_A1PLuPf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_egxhDQiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MAOrSjnr, HV_BINOP_MULTIPLY, 0, m, &cBinop_MAOrSjnr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fl74nscx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KwGIderH, HV_BINOP_MULTIPLY, 0, m, &cBinop_KwGIderH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GP3f1S7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tgYa4xj5, 0, m, &cVar_tgYa4xj5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_oUGJ0LEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oJCtGmUB, 0, m, &cVar_oJCtGmUB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JjwFvlHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QzrCEHGw, 1, m, &cIf_QzrCEHGw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MfSXwPSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_3clxlTvb, m);
}

void Heavy_WSTD_FL3NGR::cBinop_2D2MUfF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MfSXwPSk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_OzqSDDuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QzrCEHGw, 0, m, &cIf_QzrCEHGw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_zG2xdPZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cbp4mVFg, HV_BINOP_DIVIDE, 0, m, &cBinop_cbp4mVFg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_apT5qN4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dct0VU3s, HV_BINOP_DIVIDE, 1, m, &cBinop_Dct0VU3s_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cbp4mVFg, HV_BINOP_DIVIDE, 1, m, &cBinop_cbp4mVFg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_Liv1xofv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mjP5At0o, HV_BINOP_DIVIDE, 0, m, &cBinop_mjP5At0o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_u9HNOlX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mjP5At0o, HV_BINOP_DIVIDE, 1, m, &cBinop_mjP5At0o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_bVIYhssp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dct0VU3s, HV_BINOP_DIVIDE, 0, m, &cBinop_Dct0VU3s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_eAVwyGgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zG2xdPZU, 0, m, &cVar_zG2xdPZU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_smi7V09g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_apT5qN4y, 0, m, &cVar_apT5qN4y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Dct0VU3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_Liv1xofv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cbp4mVFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_u9HNOlX3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mjP5At0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_NjZ3wUmg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_s8WOlY1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_9OE11WEn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qAy3eyGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_7AkM9Iu4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NjZ3wUmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qAy3eyGL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7AkM9Iu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_s8WOlY1K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9OE11WEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rTNvgkEs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_u3yM78cB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vT3kVzDv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_vK5OUN6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xITpsE2D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ae0J40th_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0ZQtOBwu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_WUgEtXcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X94oa4SY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Jr6mWUTQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yO1RVFWB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_GVMs4v4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6kgoKhO8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_kvbkU1Ky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5VQliUU5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_dC9UnAXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K8LwIwJ4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_BZ4XPGa7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jAB2ZzkJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_zta7rJxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_phE6A78T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_zcowAZqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O53YFJGa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_fuoA6XHi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JWG6SXYe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_6rHdQjyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_yY0Wt7gX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yY0Wt7gX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_PKtSgFhN, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Q0Zvb81b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8jUy6ooA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_8jUy6ooA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_VrBcac8W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_bydYGpMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_puojNZgK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_zjY68tYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_aURmFctf_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qRiHwXkq, m);
}

void Heavy_WSTD_FL3NGR::cBinop_VrBcac8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FtK6OlYb, m);
}

void Heavy_WSTD_FL3NGR::cMsg_puojNZgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zjY68tYP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aURmFctf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GznrWz29, m);
}

void Heavy_WSTD_FL3NGR::cMsg_WUi4YYkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8RcpBMo8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_8RcpBMo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_GIkToaOU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_00HrO7Zf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tuTu7r9D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_w5ZzjLYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_wUqauSxF_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ZoiTSAtY, m);
}

void Heavy_WSTD_FL3NGR::cBinop_GIkToaOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_MgzHn8aG, m);
}

void Heavy_WSTD_FL3NGR::cMsg_tuTu7r9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_w5ZzjLYS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wUqauSxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_vQLKN5WR, m);
}

void Heavy_WSTD_FL3NGR::cBinop_9pO2WiB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_edEkbDMs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_edEkbDMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_IzgJwMU1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_Mu8ycLJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VQM5mdyV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_jzWQvUP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3SKGRQg9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_IzgJwMU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_z4AM269D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_z4AM269D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KqxT6KjL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XqSWXeZx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XqSWXeZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5YTxjV1c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_KqxT6KjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_TD439tmL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TD439tmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nDyNArrV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5YTxjV1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LrOWsy3z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LrOWsy3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tBrcAztm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nDyNArrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_Mu8ycLJj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tBrcAztm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_jzWQvUP0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_g5Zh4dI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_npzwgnhj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_npzwgnhj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jvV6xWeW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_omUIl3Yg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OM70DZEC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_OM70DZEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4nSLN5EO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_xWsqI3xQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xWsqI3xQ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3gGFpiT3, 0, m, &cDelay_3gGFpiT3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xWsqI3xQ, 0, m, &cDelay_xWsqI3xQ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_HrtSMXdV, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_3gGFpiT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3gGFpiT3, m);
  cMsg_SfGgKCsA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_xBHXT24x_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_vNvFs35y_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_9NG478va_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_92qCAUjO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_yqMtosOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tcx3xKFp_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xWsqI3xQ, 2, m, &cDelay_xWsqI3xQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E4G8s3dF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_92qCAUjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_yqMtosOF, 0, m, &hTable_yqMtosOF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4nSLN5EO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_9NG478va_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_SfGgKCsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_yqMtosOF, 0, m, &hTable_yqMtosOF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_E4G8s3dF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xWsqI3xQ, 0, m, &cDelay_xWsqI3xQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Tcx3xKFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_3gGFpiT3, 2, m, &cDelay_3gGFpiT3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_vNvFs35y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_HrtSMXdV, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_SoQYVcrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XNyQfn0v_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_XNyQfn0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gWKC1cMT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_66Z2pg7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_66Z2pg7I, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PvauYTdd, 0, m, &cDelay_PvauYTdd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_66Z2pg7I, 0, m, &cDelay_66Z2pg7I_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_FZ96nbf0, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_PvauYTdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PvauYTdd, m);
  cMsg_UI8l3PLK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_6Sf8vLAI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_rbW0GOXS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_1pPruW3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b0n7ggZN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_cA5rHVGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nga3wkjY_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_66Z2pg7I, 2, m, &cDelay_66Z2pg7I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xQ7sA2xX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_b0n7ggZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_cA5rHVGy, 0, m, &hTable_cA5rHVGy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gWKC1cMT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_1pPruW3l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_UI8l3PLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_cA5rHVGy, 0, m, &hTable_cA5rHVGy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xQ7sA2xX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_66Z2pg7I, 0, m, &cDelay_66Z2pg7I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_nga3wkjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_PvauYTdd, 2, m, &cDelay_PvauYTdd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_rbW0GOXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_FZ96nbf0, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_ytZSxJf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iSoGKR7l, HV_BINOP_MULTIPLY, 0, m, &cBinop_iSoGKR7l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wRTYSkz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kMN6gTWS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_kMN6gTWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2OwZC2Mx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_iSoGKR7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vEJJCQet_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IAhcXDN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iSoGKR7l, HV_BINOP_MULTIPLY, 1, m, &cBinop_iSoGKR7l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2OwZC2Mx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_IAhcXDN6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vEJJCQet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_reezhiqA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_reezhiqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_1FCJstDn_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_B6wMxdw2, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1FCJstDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8cQ0Z1SL, m);
}

void Heavy_WSTD_FL3NGR::cVar_RlWmaYsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OSjq60jv, HV_BINOP_MULTIPLY, 0, m, &cBinop_OSjq60jv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_zwuyVm2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_b6eDu6Ou_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_b6eDu6Ou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hc4BnhRK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_OSjq60jv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_bXneDQUw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DoQnDs9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OSjq60jv, HV_BINOP_MULTIPLY, 1, m, &cBinop_OSjq60jv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_hc4BnhRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_DoQnDs9l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bXneDQUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Lx4kLPj7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Lx4kLPj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_iB5CcxWd_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_9V1erVNx, m);
}

void Heavy_WSTD_FL3NGR::cBinop_iB5CcxWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_E8GEDKxl, m);
}

void Heavy_WSTD_FL3NGR::cMsg_jvV6xWeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XBEQuLmN, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_FKqHSw64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_UhH7CXqI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7ZV1whqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_6T8Ct978_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_n2wA1mdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_FKqHSw64_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ytnrT6jk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_UXgceaIC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UXgceaIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rvLO13vB, HV_BINOP_MULTIPLY, 1, m, &cBinop_rvLO13vB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6T8Ct978_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_ytnrT6jk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rvLO13vB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k5MD9YwU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UhH7CXqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rvLO13vB, HV_BINOP_MULTIPLY, 0, m, &cBinop_rvLO13vB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_k5MD9YwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AFbtw5q2, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_g2WVSxo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_yHOdryzQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yHOdryzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7ZV1whqP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n2wA1mdi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_qQj9sOdF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dAdfopJ2, 0, m, &cSlice_dAdfopJ2_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1ESRcNKb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_dAdfopJ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DvzQYOp8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DvzQYOp8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_3iJk0VsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DvzQYOp8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_DvzQYOp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0EfJJvZs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_1ESRcNKb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Qz5bT7ZJ, 0, m, &cSlice_Qz5bT7ZJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pon7YXIX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Qz5bT7ZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NCU1vl4G_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NCU1vl4G_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_Ll1qvABW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NCU1vl4G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_NCU1vl4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8gbXe7aW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_pon7YXIX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Da91M7WI, 0, m, &cSlice_Da91M7WI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_HWt8ROhn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Da91M7WI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jAaG7JA4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jAaG7JA4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_DJz112Ky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jAaG7JA4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_jAaG7JA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_b655zMxW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_HWt8ROhn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_T1LzUh28, 0, m, &cSlice_T1LzUh28_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_T1LzUh28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QFay9ZoT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QFay9ZoT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_DGn0Kp7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QFay9ZoT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_QFay9ZoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eJLJlvFx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_VQM5mdyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0jiNV161, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_3SKGRQg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jPdgON4x, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_RtfRlDzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_uYtCQPhS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uYtCQPhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_S3AGkLt4, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_zc72v0Js_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3nAQUNam_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_3nAQUNam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_0rxBuFh6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_uCklAfr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RgKPl7Xb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_iLQVfgi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PCyMTn9U_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_TOdcFi3O, m);
}

void Heavy_WSTD_FL3NGR::cBinop_0rxBuFh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_LoWaK0qK, m);
}

void Heavy_WSTD_FL3NGR::cMsg_RgKPl7Xb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_iLQVfgi9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PCyMTn9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_RzM33K7i, m);
}

void Heavy_WSTD_FL3NGR::cMsg_rqwqOOgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QHxV36fZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_QHxV36fZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_rnxh8wCP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_4NMyQRgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C64Ba5pl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_pELpZhVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_zo9yZJYG_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_OTBuV27I, m);
}

void Heavy_WSTD_FL3NGR::cBinop_rnxh8wCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_jQCZc222, m);
}

void Heavy_WSTD_FL3NGR::cMsg_C64Ba5pl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pELpZhVI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zo9yZJYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_do2dLbHW, m);
}

void Heavy_WSTD_FL3NGR::cBinop_55y8xvMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_x7CjyKxc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_x7CjyKxc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_vJqfQiep_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_OxORqGjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SPTKbnr3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_MjSxx3UI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_keRr6rS0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vJqfQiep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qQO4xoKW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qQO4xoKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d6PdVs56_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EAPg9uzh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_EAPg9uzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VkyY6yIQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_d6PdVs56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_CFgZtxdO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CFgZtxdO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sGYItpkr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_VkyY6yIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_x4FC0fCA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_x4FC0fCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Fh0c3NiM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sGYItpkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_OxORqGjv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Fh0c3NiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_MjSxx3UI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ACkCq0wi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ZIs5plz3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZIs5plz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SyRX1LnH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_FD1o0cmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YkPTZKUn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_YkPTZKUn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_3pw0GL1I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_0JrHzV5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0JrHzV5G, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_u8me2fd4, 0, m, &cDelay_u8me2fd4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0JrHzV5G, 0, m, &cDelay_0JrHzV5G_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_NSZR8yTG, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_u8me2fd4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_u8me2fd4, m);
  cMsg_xz4RCWeG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_7zKaBQ7L_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ZlAd7ahI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_68ClxctP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YsFE4zy5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_uKorntAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xDjMPYIx_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0JrHzV5G, 2, m, &cDelay_0JrHzV5G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NrMdooHb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_YsFE4zy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_uKorntAo, 0, m, &hTable_uKorntAo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3pw0GL1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_68ClxctP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_xz4RCWeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_uKorntAo, 0, m, &hTable_uKorntAo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_NrMdooHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0JrHzV5G, 0, m, &cDelay_0JrHzV5G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_xDjMPYIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_u8me2fd4, 2, m, &cDelay_u8me2fd4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ZlAd7ahI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_NSZR8yTG, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_cPyTplNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_77xVHZbi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_77xVHZbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9pejWumC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_XL20srPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XL20srPa, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_w7O8ErbI, 0, m, &cDelay_w7O8ErbI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XL20srPa, 0, m, &cDelay_XL20srPa_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_0fFr9Nwq, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_w7O8ErbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_w7O8ErbI, m);
  cMsg_RLfNbjZY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_aNq1A5Nv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_JwN4C6sP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_D4SJVlfS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_odnuiqXc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_OQxq8Ffk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3CApDJeC_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XL20srPa, 2, m, &cDelay_XL20srPa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bhxVpgI0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_odnuiqXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_OQxq8Ffk, 0, m, &hTable_OQxq8Ffk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9pejWumC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_D4SJVlfS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_RLfNbjZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_OQxq8Ffk, 0, m, &hTable_OQxq8Ffk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_bhxVpgI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XL20srPa, 0, m, &cDelay_XL20srPa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3CApDJeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_w7O8ErbI, 2, m, &cDelay_w7O8ErbI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_JwN4C6sP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_0fFr9Nwq, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_XojjstJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YlHrAcd8, HV_BINOP_MULTIPLY, 0, m, &cBinop_YlHrAcd8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_YNyrW87n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PnXys808_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_PnXys808_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SY0JP097_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_YlHrAcd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rjmGZ8Mx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jVctWLsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YlHrAcd8, HV_BINOP_MULTIPLY, 1, m, &cBinop_YlHrAcd8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_SY0JP097_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_jVctWLsW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rjmGZ8Mx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Vdov5NP2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Vdov5NP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_02V6fUXU_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_XpCqdZun, m);
}

void Heavy_WSTD_FL3NGR::cBinop_02V6fUXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0DRmFUUG, m);
}

void Heavy_WSTD_FL3NGR::cVar_Z23cSxQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6I5NfusO, HV_BINOP_MULTIPLY, 0, m, &cBinop_6I5NfusO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_UeSHQZjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_806CS9xN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_806CS9xN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tlbcwtBE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_6I5NfusO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_3TAZhOyI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dSUVwV6j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6I5NfusO, HV_BINOP_MULTIPLY, 1, m, &cBinop_6I5NfusO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_tlbcwtBE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_dSUVwV6j_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3TAZhOyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_edLsi1fI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_edLsi1fI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_YIi41f0N_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_UYWVKOTx, m);
}

void Heavy_WSTD_FL3NGR::cBinop_YIi41f0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_zZwGYQV7, m);
}

void Heavy_WSTD_FL3NGR::cMsg_SyRX1LnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bZHEiyDW, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_6ZiqxCpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_oyaMTVwP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_b7NrmBdS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_8wbJUOzO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_cGsuB0ov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_6ZiqxCpY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_A4BP3ck0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_vCywWk1w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vCywWk1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QqEcsYLT, HV_BINOP_MULTIPLY, 1, m, &cBinop_QqEcsYLT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8wbJUOzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_A4BP3ck0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QqEcsYLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O1NFx9fz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_oyaMTVwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QqEcsYLT, HV_BINOP_MULTIPLY, 0, m, &cBinop_QqEcsYLT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_O1NFx9fz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sQoC69mn, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_BKl4ykUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_Y7PdYxex_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Y7PdYxex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b7NrmBdS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cGsuB0ov_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_QRY5srOB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mgBV9XZB, 0, m, &cSlice_mgBV9XZB_sendMessage);
      break;
    }
    default: {
      cSwitchcase_yp9msTyp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_mgBV9XZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_f28IC7ku_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_f28IC7ku_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_cR1rlkcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f28IC7ku_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_f28IC7ku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Y2s1PKE8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_yp9msTyp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3bDrqM6P, 0, m, &cSlice_3bDrqM6P_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KCgJQnDX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_3bDrqM6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JmxVjODG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JmxVjODG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_jGLVSL5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JmxVjODG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_JmxVjODG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_g1Y5Rs2e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_KCgJQnDX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sBZNdjWc, 0, m, &cSlice_sBZNdjWc_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nmJZrEI4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_sBZNdjWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Ac4P0Ano_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Ac4P0Ano_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_R2BwKhu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ac4P0Ano_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Ac4P0Ano_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_auf4mN6V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_nmJZrEI4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ckWyPnJY, 0, m, &cSlice_ckWyPnJY_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_ckWyPnJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qVwtHDdp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qVwtHDdp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_hR5AHuFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qVwtHDdp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_qVwtHDdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9yeFwqTS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_SPTKbnr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8TQojPiB, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_keRr6rS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IoocO4T4, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_UwiilcoZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ZsBrDlFa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZsBrDlFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_rYky22Ca, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_rEjrsyut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TL1brS1P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_TL1brS1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_fhyUZcTC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_WYHcJeTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iGNNRJcl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_rZmw5XUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pJVG9B4d_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_kbv6M6CY, m);
}

void Heavy_WSTD_FL3NGR::cBinop_fhyUZcTC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GdUE3vsn, m);
}

void Heavy_WSTD_FL3NGR::cMsg_iGNNRJcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rZmw5XUL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pJVG9B4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6MDJQqru, m);
}

void Heavy_WSTD_FL3NGR::cMsg_nDMmczbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8tzArbe3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_8tzArbe3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_XWsL1c07_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Jz76m2ot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hQz79JuF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_PHJIWagv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ElgmIRlC_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wvsh1eQs, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XWsL1c07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qWp3pLq2, m);
}

void Heavy_WSTD_FL3NGR::cMsg_hQz79JuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PHJIWagv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ElgmIRlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3Hxo7URY, m);
}

void Heavy_WSTD_FL3NGR::cBinop_pqoPzx5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_5PAK6FoT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5PAK6FoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_TKcNV4tf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_0kiIOIxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o4ZVfpPB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_z0uYJx68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eUNPjymf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_TKcNV4tf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_xuPFb4SS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xuPFb4SS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m5UuCtNi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H87IWX3w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_m5UuCtNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_nknc0EJN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_H87IWX3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KgehQIES_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nknc0EJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Q37gdUFF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KgehQIES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Sbrv9AoI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Sbrv9AoI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_VsiAKydm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Q37gdUFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_0kiIOIxF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VsiAKydm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_z0uYJx68_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LN5amLfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_2NBrpGCB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2NBrpGCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PjkKbcBd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_gZYliKF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ERyk8VlA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_ERyk8VlA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2pwGPPjW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_zGbFcZ1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zGbFcZ1n, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_31ftR8ob, 0, m, &cDelay_31ftR8ob_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zGbFcZ1n, 0, m, &cDelay_zGbFcZ1n_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_g1i8JYvN, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_31ftR8ob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_31ftR8ob, m);
  cMsg_fpoTAqCE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_tOHCPdiD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_GMOVRSpC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_EvQNEiw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g1vflkgY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_esHiXFKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WlZTBtXa_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zGbFcZ1n, 2, m, &cDelay_zGbFcZ1n_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dd9Js6Jz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_g1vflkgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_esHiXFKQ, 0, m, &hTable_esHiXFKQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2pwGPPjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_EvQNEiw3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_fpoTAqCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_esHiXFKQ, 0, m, &hTable_esHiXFKQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_dd9Js6Jz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zGbFcZ1n, 0, m, &cDelay_zGbFcZ1n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_WlZTBtXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_31ftR8ob, 2, m, &cDelay_31ftR8ob_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_GMOVRSpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_g1i8JYvN, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_9biz2dJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Z447bvDV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Z447bvDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_e95b69t5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_5CWPZ3RV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5CWPZ3RV, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EQH2RqTw, 0, m, &cDelay_EQH2RqTw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5CWPZ3RV, 0, m, &cDelay_5CWPZ3RV_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_JFdU9lxR, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_EQH2RqTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EQH2RqTw, m);
  cMsg_krt7zafo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_yqpBOdaz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_PnYgqbuR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_cDalpzGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xd48II9F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_J4RDg2Sc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9MDJPk8L_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5CWPZ3RV, 2, m, &cDelay_5CWPZ3RV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XZ6YfGoQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_xd48II9F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_J4RDg2Sc, 0, m, &hTable_J4RDg2Sc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_e95b69t5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_cDalpzGc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_krt7zafo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_J4RDg2Sc, 0, m, &hTable_J4RDg2Sc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XZ6YfGoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5CWPZ3RV, 0, m, &cDelay_5CWPZ3RV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_9MDJPk8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_EQH2RqTw, 2, m, &cDelay_EQH2RqTw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_PnYgqbuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_JFdU9lxR, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_5et4EJcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_20QW4pWF, HV_BINOP_MULTIPLY, 0, m, &cBinop_20QW4pWF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_r09so9is_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7HA2qKIj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_7HA2qKIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eabQiAj8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_20QW4pWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_tkPrubx2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZHjipHtG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_20QW4pWF, HV_BINOP_MULTIPLY, 1, m, &cBinop_20QW4pWF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_eabQiAj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZHjipHtG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tkPrubx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ackHxCWr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ackHxCWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_n2KI4Gbd_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_exHquYAF, m);
}

void Heavy_WSTD_FL3NGR::cBinop_n2KI4Gbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_X9pDy92m, m);
}

void Heavy_WSTD_FL3NGR::cVar_jB8jqRXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kWjl9P9p, HV_BINOP_MULTIPLY, 0, m, &cBinop_kWjl9P9p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4y6Bj7bs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_v9t7khej_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_v9t7khej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3NHA1frz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_kWjl9P9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vuUpVVJh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0DXt9AUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kWjl9P9p, HV_BINOP_MULTIPLY, 1, m, &cBinop_kWjl9P9p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3NHA1frz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0DXt9AUK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vuUpVVJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Wbv0pOin_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Wbv0pOin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_KtNPWZQF_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_s3mBbyJc, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KtNPWZQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_EvQpJptB, m);
}

void Heavy_WSTD_FL3NGR::cMsg_PjkKbcBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_D7X0e3Oc, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_YalTWZvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_hhUz3lGO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5Y8DEFap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VKOA1wIL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ixOlYXVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_YalTWZvo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xCS4ECkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_YZnavQmu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YZnavQmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zYlx6IZE, HV_BINOP_MULTIPLY, 1, m, &cBinop_zYlx6IZE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VKOA1wIL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_xCS4ECkE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zYlx6IZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3PB8QasX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_hhUz3lGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zYlx6IZE, HV_BINOP_MULTIPLY, 0, m, &cBinop_zYlx6IZE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3PB8QasX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_77mqAowP, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_eNjABH5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_XcHtIszF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XcHtIszF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5Y8DEFap_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ixOlYXVW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_epdTTocG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SEZrFlsX, 0, m, &cSlice_SEZrFlsX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jW2xVBXR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_SEZrFlsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XcJWeQKQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XcJWeQKQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_6uIGnpA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XcJWeQKQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_XcJWeQKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_K6dFJk6p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_jW2xVBXR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rPsHwubX, 0, m, &cSlice_rPsHwubX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_cfPCMQ6A_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_rPsHwubX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BGZsAPGI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BGZsAPGI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_3qbsQPtS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BGZsAPGI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_BGZsAPGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1E7GnJOs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_cfPCMQ6A_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_s3FZP5we, 0, m, &cSlice_s3FZP5we_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jPz71yBp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_s3FZP5we_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_70GzR1lV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_70GzR1lV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_mwxD98dX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_70GzR1lV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_70GzR1lV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_e6NHv0Hi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_jPz71yBp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SrBjvUhL, 0, m, &cSlice_SrBjvUhL_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_SrBjvUhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VzQi4Yiv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VzQi4Yiv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_k16CXNHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VzQi4Yiv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_VzQi4Yiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BtN6YpIG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_o4ZVfpPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_D8ogDojP, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_eUNPjymf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uPnfAmee, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_QD3HxASa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SsD8oXmt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cXOjpUZY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_1HtseAzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SsD8oXmt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cXOjpUZY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_MuJQRIyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SsD8oXmt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cXOjpUZY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_lD9Gmt92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SsD8oXmt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cXOjpUZY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_rTNvgkEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SsD8oXmt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_cXOjpUZY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ghENy1RK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_uHLQXCqW, 0, m, &cVar_uHLQXCqW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_gSNH1jpM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_oz7C4UyQ, 0, m, &cVar_oz7C4UyQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ldEwEk0A, 0, m, &cVar_ldEwEk0A_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cFNayMOe, 0, m, &cVar_cFNayMOe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_X94oa4SY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_qQj9sOdF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_vT3kVzDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_qQj9sOdF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_xITpsE2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_qQj9sOdF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_0ZQtOBwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_qQj9sOdF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_j6Re6ERa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WUgEtXcE, 0, m, &cVar_WUgEtXcE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_G5y4fnRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_u3yM78cB, 0, m, &cVar_u3yM78cB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_18q5PRP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ae0J40th, 0, m, &cVar_ae0J40th_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_K8LwIwJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_QRY5srOB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_yO1RVFWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_QRY5srOB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_6kgoKhO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_QRY5srOB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_5VQliUU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_QRY5srOB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_wSlHmWsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dC9UnAXF, 0, m, &cVar_dC9UnAXF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_05q9c5a9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jr6mWUTQ, 0, m, &cVar_Jr6mWUTQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_axifT071_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kvbkU1Ky, 0, m, &cVar_kvbkU1Ky_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_JWG6SXYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_epdTTocG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_jAB2ZzkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_epdTTocG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_phE6A78T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_epdTTocG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_O53YFJGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_epdTTocG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_B13KKmeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fuoA6XHi, 0, m, &cVar_fuoA6XHi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xkf3COCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BZ4XPGa7, 0, m, &cVar_BZ4XPGa7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mVUY9GRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zcowAZqI, 0, m, &cVar_zcowAZqI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_izEwVxrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oz7C4UyQ, 0, m, &cVar_oz7C4UyQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_b1RiTSrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ldEwEk0A, 0, m, &cVar_ldEwEk0A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_feN3IS4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cFNayMOe, 0, m, &cVar_cFNayMOe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_bolGImOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M7UNEPrf, 0, m, &cVar_M7UNEPrf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_mnoWQ4Fl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pl4KSR7X_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Px8C1wBb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_l7FSz5hg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0QQyYumq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0muHKbfr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JyPucR74_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_l09rkrRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E6U8Qk8M_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8xylhMks_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XxiAJj9B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_re0pWw3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QniJ4K2Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U6daj67v_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GZYWmXiH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_HDFVhTl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hObSl0Ti_sendMessage(_c, 0, m);
  cMsg_ibsdLFeQ_sendMessage(_c, 0, m);
  cMsg_hXtQo94o_sendMessage(_c, 0, m);
  cMsg_2Is0qo6M_sendMessage(_c, 0, m);
  cMsg_I5kCuagl_sendMessage(_c, 0, m);
  cMsg_AeR2A8ri_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_AnZbbXRp, 0, m, &cVar_AnZbbXRp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_M7UNEPrf, 0, m, &cVar_M7UNEPrf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4BD9Jdp2, 0, m, &cVar_4BD9Jdp2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bpg6j99l, 0, m, &cVar_bpg6j99l_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uxNTZpqS, 0, m, &cVar_uxNTZpqS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RPOUuqrI, 0, m, &cVar_RPOUuqrI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iMdy0TWo, 0, m, &cVar_iMdy0TWo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cUc0cRCh, 0, m, &cVar_cUc0cRCh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xBwCBx3o, 0, m, &cVar_xBwCBx3o_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iUm41Ccy, 0, m, &cVar_iUm41Ccy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xEY5fKVz, 0, m, &cVar_xEY5fKVz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VVlbafAc, 0, m, &cVar_VVlbafAc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7EFwl6WE, 0, m, &cVar_7EFwl6WE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JEAlLkZg, 0, m, &cVar_JEAlLkZg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TJCeWTFL, 0, m, &cVar_TJCeWTFL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EjLhABz0, 0, m, &cVar_EjLhABz0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NKDjhzUN, 0, m, &cVar_NKDjhzUN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ldGrKpnj, 0, m, &cVar_ldGrKpnj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uPwabecF, 0, m, &cVar_uPwabecF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8hsryfdK, 0, m, &cVar_8hsryfdK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LF44zxdI, 0, m, &cVar_LF44zxdI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QqhdjAnx, 0, m, &cVar_QqhdjAnx_sendMessage);
  cMsg_wRTYSkz7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ytZSxJf3, 0, m, &cVar_ytZSxJf3_sendMessage);
  cMsg_zwuyVm2w_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RlWmaYsQ, 0, m, &cVar_RlWmaYsQ_sendMessage);
  cMsg_YNyrW87n_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_XojjstJD, 0, m, &cVar_XojjstJD_sendMessage);
  cMsg_UeSHQZjY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Z23cSxQP, 0, m, &cVar_Z23cSxQP_sendMessage);
  cMsg_r09so9is_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5et4EJcH, 0, m, &cVar_5et4EJcH_sendMessage);
  cMsg_4y6Bj7bs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jB8jqRXd, 0, m, &cVar_jB8jqRXd_sendMessage);
  cMsg_omUIl3Yg_sendMessage(_c, 0, m);
  cMsg_SoQYVcrS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3iJk0VsI, 0, m, &cVar_3iJk0VsI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ll1qvABW, 0, m, &cVar_Ll1qvABW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DJz112Ky, 0, m, &cVar_DJz112Ky_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DGn0Kp7y, 0, m, &cVar_DGn0Kp7y_sendMessage);
  cMsg_FD1o0cmi_sendMessage(_c, 0, m);
  cMsg_cPyTplNo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_cR1rlkcN, 0, m, &cVar_cR1rlkcN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jGLVSL5u, 0, m, &cVar_jGLVSL5u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_R2BwKhu3, 0, m, &cVar_R2BwKhu3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hR5AHuFY, 0, m, &cVar_hR5AHuFY_sendMessage);
  cMsg_gZYliKF3_sendMessage(_c, 0, m);
  cMsg_9biz2dJ8_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_6uIGnpA3, 0, m, &cVar_6uIGnpA3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3qbsQPtS, 0, m, &cVar_3qbsQPtS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mwxD98dX, 0, m, &cVar_mwxD98dX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_k16CXNHw, 0, m, &cVar_k16CXNHw_sendMessage);
  cMsg_gSNH1jpM_sendMessage(_c, 0, m);
  cMsg_ghENy1RK_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bydYGpMA, 0, m, &cVar_bydYGpMA_sendMessage);
  cMsg_Q0Zvb81b_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_00HrO7Zf, 0, m, &cVar_00HrO7Zf_sendMessage);
  cMsg_WUi4YYkJ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uCklAfr1, 0, m, &cVar_uCklAfr1_sendMessage);
  cMsg_zc72v0Js_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_4NMyQRgF, 0, m, &cVar_4NMyQRgF_sendMessage);
  cMsg_rqwqOOgs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_WYHcJeTW, 0, m, &cVar_WYHcJeTW_sendMessage);
  cMsg_rEjrsyut_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Jz76m2ot, 0, m, &cVar_Jz76m2ot_sendMessage);
  cMsg_nDMmczbo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_deK811wD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nhvgmdwr, HV_BINOP_MULTIPLY, 0, m, &cBinop_Nhvgmdwr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ayIas8Mu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RYBOdq2u_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_4FBFRBBf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_h4GrElv4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_AQa11xgA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ulzhlo5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_X0EoASog_sendMessage);
  cMsg_F4Iu8y6s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_Li6dJvbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uRZJ7YrB, HV_BINOP_MULTIPLY, 0, m, &cBinop_uRZJ7YrB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_2x4gfkcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ayG3TiOu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_U6BzHMbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XUyecwPP, HV_BINOP_MULTIPLY, 1, m, &cBinop_XUyecwPP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_mAwaSdEe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_WvpoA00A_sendMessage);
  cMsg_CTrpwVEQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_bNl79CWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iDZIJop5, HV_BINOP_MULTIPLY, 0, m, &cBinop_iDZIJop5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_w4241gNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_08q7LWnG_sendMessage(_c, 0, m);
  cMsg_C8E4q7UQ_sendMessage(_c, 0, m);
  cMsg_J6yAstV5_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_PqfemkPO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_a8Eg38YJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_paPDPmVJ_sendMessage);
  cMsg_4EzVXu4b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_965Z5LKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uxNTZpqS, 0, m, &cVar_uxNTZpqS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_2dc2MOpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_teqAtCPh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ny1eLUmU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_slWTKAzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bKmfzh5A_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gIyYMAvc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZrFhIK4L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_yelYJoxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2ADgg6Q8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8H8apbNR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wyBeiXIb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_CfgmlheR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xPhTY4xy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eHgCOpz2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oAv6FF26_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_FIuJl2vN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sPsrBRKy, HV_BINOP_MULTIPLY, 0, m, &cBinop_sPsrBRKy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ngjt9Jt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Cz7wJuDV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_XAp0bDUd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_6oku71uF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_q7rWNBpC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_vvUnd7o0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_q59KIdI3_sendMessage);
  cMsg_vOJj7enF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_tvIjN2nJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nth0L5us, HV_BINOP_MULTIPLY, 0, m, &cBinop_nth0L5us_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_02tLTmgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_8A1KFzqf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_7y9lfVAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w6vMObcW, HV_BINOP_MULTIPLY, 1, m, &cBinop_w6vMObcW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UzQ8wubl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_UzE937Kz_sendMessage);
  cMsg_9sZnhhMv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_Mc5Fw526_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a3CzXAXe, HV_BINOP_MULTIPLY, 0, m, &cBinop_a3CzXAXe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_QHO4BUrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0f1xYyDO_sendMessage(_c, 0, m);
  cMsg_ORToJQls_sendMessage(_c, 0, m);
  cMsg_O6oAZfbF_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_N9LAkCJz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_3Ne7bMJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_eJ0TtcuO_sendMessage);
  cMsg_2seDt9Mb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_tFkYaBXj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uHLQXCqW, 0, m, &cVar_uHLQXCqW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_TimPVNEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_j6Re6ERa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ODi7okHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_G5y4fnRw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_bykNCjpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vK5OUN6V, 0, m, &cVar_vK5OUN6V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_LHSQgGOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_18q5PRP0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_0zKbPPxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_wSlHmWsu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_rtSMb2xe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_05q9c5a9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_plpcXgdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GVMs4v4t, 0, m, &cVar_GVMs4v4t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_XvepOB2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_axifT071_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_RaeRpQo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_B13KKmeo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_PIc1Db9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_xkf3COCW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_3diylgP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zta7rJxS, 0, m, &cVar_zta7rJxS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_CTw6QVnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_mVUY9GRN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_b655zMxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_6rHdQjyX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_8gbXe7aW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_g2WVSxo1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_eJLJlvFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_9pO2WiB6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_0EfJJvZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_g5Zh4dI8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_auf4mN6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_RtfRlDzo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_g1Y5Rs2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_BKl4ykUe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_9yeFwqTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_55y8xvMO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Y2s1PKE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ACkCq0wi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_e6NHv0Hi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_UwiilcoZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_1E7GnJOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_eNjABH5z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_BtN6YpIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pqoPzx5d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_K6dFJk6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_LN5amLfD_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FL3NGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_tcqCC40R, VOf(Bf0));
    __hv_line_f(&sLine_7iI2FIwz, VOf(Bf1));
    __hv_line_f(&sLine_kcBju681, VOf(Bf2));
    __hv_line_f(&sLine_rEHoyQz2, VOf(Bf3));
    __hv_line_f(&sLine_JXeZvpQL, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_b2Wqmk5H, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_9tooU4Uk, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_cTcU1J1G, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_aToP3TOa, VOf(Bf1));
    __hv_line_f(&sLine_iGlLF8XB, VOf(Bf0));
    __hv_line_f(&sLine_y4nENucK, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_bQ1V9l5F, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_iNCmDaUN, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_fp0Wa5tk, VOf(Bf5));
    __hv_line_f(&sLine_x8nV1y5C, VOf(Bf1));
    __hv_line_f(&sLine_rFtgVc5Y, VOf(Bf2));
    __hv_line_f(&sLine_2rbWQfBq, VOf(Bf4));
    __hv_line_f(&sLine_i8mIQpUl, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_WMjjMP0H, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_BF8IelrZ, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_mHiMPZQj, VOf(Bf6));
    __hv_line_f(&sLine_4d5kDSLq, VOf(Bf2));
    __hv_line_f(&sLine_J7qbvHRr, VOf(Bf1));
    __hv_line_f(&sLine_H70voZQM, VOf(Bf5));
    __hv_line_f(&sLine_W1FLm0AB, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_qx2aLIEB, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_lXIherSm, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_9zAbs7dz, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_RYEYNDiy, VOf(Bf2));
    __hv_line_f(&sLine_XRh2uJVw, VOf(Bf6));
    __hv_line_f(&sLine_UApHMuFn, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_rNEx0T31, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_3clxlTvb, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_QDFw4tkg, VOf(Bf8));
    __hv_line_f(&sLine_lNlcjPvE, VOf(Bf2));
    __hv_line_f(&sLine_m2FqzZdX, VOf(Bf1));
    __hv_line_f(&sLine_RVr9glzQ, VOf(Bf7));
    __hv_line_f(&sLine_g6eCNDUT, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_5akfb8Mh, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_LsTXWmrX, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_jPdgON4x, VOf(Bf9));
    __hv_phasor_k_f(&sPhasor_PKtSgFhN, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_XBEQuLmN, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf10), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf1), VIf(Bf10), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf8));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf8));
    __hv_varread_f(&sVarf_B6wMxdw2, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_8cQ0Z1SL, VOf(Bf8));
    __hv_rpole_f(&sRPole_iOy1aLaI, VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_9V1erVNx, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_E8GEDKxl, VOf(Bf10));
    __hv_rpole_f(&sRPole_2zWtRCvS, VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_KXPcBWP3, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_FtK6OlYb, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_GznrWz29, VOf(Bf10));
    __hv_min_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_qRiHwXkq, VOf(Bf10));
    __hv_zero_f(VOf(Bf11));
    __hv_lt_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_and_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_cast_fi(VIf(Bf11), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_50ZHRfu7, VIi(Bi1), VOf(Bf11));
    __hv_tabread_if(&sTabread_PVpdqOV8, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf11), VIf(Bf10), VOf(Bf11));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf11), VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_0jiNV161, VOf(Bf2));
    __hv_mul_f(VIf(Bf10), VIf(Bf2), VOf(Bf11));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_tabhead_f(&sTabhead_FRebSj7W, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_MgzHn8aG, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_vQLKN5WR, VOf(Bf8));
    __hv_min_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf12));
    __hv_varread_f(&sVarf_ZoiTSAtY, VOf(Bf8));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf8), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_zShqMlpk, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_V6r0xve3, VIi(Bi0), VOf(Bf8));
    __hv_sub_f(VIf(Bf13), VIf(Bf8), VOf(Bf13));
    __hv_sub_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf2));
    __hv_fma_f(VIf(Bf9), VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_AFbtw5q2, VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_HrtSMXdV, VIf(Bf5));
    __hv_fma_f(VIf(Bf10), VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_FZ96nbf0, VIf(Bf3));
    __hv_varwrite_f(&sVarf_2PCdYxMN, VIf(Bf11));
    __hv_line_f(&sLine_IoocO4T4, VOf(Bf11));
    __hv_phasor_k_f(&sPhasor_S3AGkLt4, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_abs_f(VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf3), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf9), VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_bZHEiyDW, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf10));
    __hv_add_f(VIf(Bf10), VIf(Bf5), VOf(Bf10));
    __hv_varread_f(&sVarf_XpCqdZun, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_0DRmFUUG, VOf(Bf10));
    __hv_rpole_f(&sRPole_imalDxZF, VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_UYWVKOTx, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_zZwGYQV7, VOf(Bf5));
    __hv_rpole_f(&sRPole_tGBzcY6Z, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_2CDDGwwY, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf9), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_LoWaK0qK, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_RzM33K7i, VOf(Bf5));
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf9));
    __hv_varread_f(&sVarf_TOdcFi3O, VOf(Bf5));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_p2jMAa6p, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_V0fgmksX, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf8), VIf(Bf5), VOf(Bf8));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf8), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_8TQojPiB, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf8));
    __hv_fma_f(VIf(Bf0), VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_tabhead_f(&sTabhead_K4PO5IKi, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_jQCZc222, VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_do2dLbHW, VOf(Bf10));
    __hv_min_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf12));
    __hv_varread_f(&sVarf_OTBuV27I, VOf(Bf10));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_A3fxbbAT, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_clUWDQJk, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf13), VIf(Bf10), VOf(Bf13));
    __hv_sub_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf9));
    __hv_fma_f(VIf(Bf11), VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_sQoC69mn, VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_tabwrite_f(&sTabwrite_NSZR8yTG, VIf(Bf6));
    __hv_fma_f(VIf(Bf5), VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_0fFr9Nwq, VIf(Bf0));
    __hv_varwrite_f(&sVarf_SI0JXkSb, VIf(Bf8));
    __hv_line_f(&sLine_uPnfAmee, VOf(Bf8));
    __hv_phasor_k_f(&sPhasor_rYky22Ca, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_D7X0e3Oc, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf5));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf5));
    __hv_varread_f(&sVarf_exHquYAF, VOf(Bf11));
    __hv_mul_f(VIf(Bf5), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_X9pDy92m, VOf(Bf5));
    __hv_rpole_f(&sRPole_T5EPiauS, VIf(Bf11), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_s3mBbyJc, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_EvQpJptB, VOf(Bf6));
    __hv_rpole_f(&sRPole_wiEKCUBa, VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_tabhead_f(&sTabhead_o3Dw67tI, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf11), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_GdUE3vsn, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_6MDJQqru, VOf(Bf6));
    __hv_min_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf11));
    __hv_varread_f(&sVarf_kbv6M6CY, VOf(Bf6));
    __hv_zero_f(VOf(Bf10));
    __hv_lt_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_and_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_cast_fi(VIf(Bf10), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_Sg4QR3FX, VIi(Bi1), VOf(Bf10));
    __hv_tabread_if(&sTabread_p25QAGUp, VIi(Bi0), VOf(Bf6));
    __hv_sub_f(VIf(Bf10), VIf(Bf6), VOf(Bf10));
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_D8ogDojP, VOf(Bf11));
    __hv_mul_f(VIf(Bf6), VIf(Bf11), VOf(Bf10));
    __hv_fma_f(VIf(Bf4), VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_Uk0JYElV, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_qWp3pLq2, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_3Hxo7URY, VOf(Bf5));
    __hv_min_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf12), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf12));
    __hv_varread_f(&sVarf_wvsh1eQs, VOf(Bf5));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf5), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_xftieUDt, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_VKRQ6xQs, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf13), VIf(Bf5), VOf(Bf13));
    __hv_sub_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf11), VIf(Bf5), VOf(Bf11));
    __hv_fma_f(VIf(Bf8), VIf(Bf7), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_77mqAowP, VOf(Bf8));
    __hv_fma_f(VIf(Bf8), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_g1i8JYvN, VIf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_JFdU9lxR, VIf(Bf4));
    __hv_varwrite_f(&sVarf_Zy9O71ID, VIf(Bf10));
    __hv_varwrite_f(&sVarf_EogjcYx1, VIf(Bf2));
    __hv_varwrite_f(&sVarf_H9CV4BPL, VIf(Bf9));
    __hv_varwrite_f(&sVarf_IZjWjPTN, VIf(Bf11));
    __hv_varread_f(&sVarf_2PCdYxMN, VOf(Bf11));
    __hv_varread_f(&sVarf_SI0JXkSb, VOf(Bf9));
    __hv_varread_f(&sVarf_Zy9O71ID, VOf(Bf2));
    __hv_add_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_EogjcYx1, VOf(Bf2));
    __hv_varread_f(&sVarf_H9CV4BPL, VOf(Bf11));
    __hv_varread_f(&sVarf_IZjWjPTN, VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf9), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FL3NGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FL3NGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
